;;; cus-load.el --- custom dependencies (do not edit)   -*- lexical-binding: t -*-
;; Generated by the `custom-make-dependencies' function.

;; This file is part of GNU Emacs.

;;; Code:

(custom--add-custom-loads '5x5 '(5x5))
(custom--add-custom-loads 'LaTeX '(reftex-vars))
(custom--add-custom-loads 'PostScript '(ps-mode))
(custom--add-custom-loads 'PostScript-edit '(ps-mode))
(custom--add-custom-loads 'PostScript-interaction '(ps-mode))
(custom--add-custom-loads 'SQL '(sql))
(custom--add-custom-loads 'abbrev '(dabbrev expand hippie-exp))
(custom--add-custom-loads 'abbrev-mode '(mailabbrev))
(custom--add-custom-loads 'advice '(advice))
(custom--add-custom-loads 'align '(align))
(custom--add-custom-loads 'allout '(allout allout-widgets))
(custom--add-custom-loads 'allout-encryption '(allout))
(custom--add-custom-loads 'allout-keybindings '(allout))
(custom--add-custom-loads 'allout-widgets '(allout-widgets))
(custom--add-custom-loads 'allout-widgets-developer '(allout-widgets))
(custom--add-custom-loads 'ange-ftp '(ange-ftp))
(custom--add-custom-loads 'animate '(animate))
(custom--add-custom-loads 'ansi-colors '(ansi-color))
(custom--add-custom-loads 'ansi-osc '(ansi-osc))
(custom--add-custom-loads 'antlr '(antlr-mode))
(custom--add-custom-loads 'applications '(calc calculator calendar cus-edit dictionary doc-view eglot erc eshell htmlfontify ispell mpc newst-backend package rcirc ses))
(custom--add-custom-loads 'appt '(appt))
(custom--add-custom-loads 'apropos '(apropos))
(custom--add-custom-loads 'archive '(arc-mode))
(custom--add-custom-loads 'archive-7z '(arc-mode))
(custom--add-custom-loads 'archive-arc '(arc-mode))
(custom--add-custom-loads 'archive-lzh '(arc-mode))
(custom--add-custom-loads 'archive-squashfs '(arc-mode))
(custom--add-custom-loads 'archive-zip '(arc-mode))
(custom--add-custom-loads 'archive-zoo '(arc-mode))
(custom--add-custom-loads 'artist '(artist))
(custom--add-custom-loads 'artist-text '(artist))
(custom--add-custom-loads 'asm '(asm-mode))
(custom--add-custom-loads 'auth-source '(auth-source auth-source-pass))
(custom--add-custom-loads 'auth-source-pass '(auth-source-pass))
(custom--add-custom-loads 'auto-insert '(autoinsert))
(custom--add-custom-loads 'auto-revert '(autorevert))
(custom--add-custom-loads 'avoid '(avoid))
(custom--add-custom-loads 'backtrace '(backtrace))
(custom--add-custom-loads 'basic-faces '(cus-edit shadowfile tab-line))
(custom--add-custom-loads 'bat-mode '(bat-mode))
(custom--add-custom-loads 'battery '(battery))
(custom--add-custom-loads 'bib '(bib-mode))
(custom--add-custom-loads 'bibtex '(bibtex bibtex-style))
(custom--add-custom-loads 'bibtex-autokey '(bibtex))
(custom--add-custom-loads 'bind-key '(bind-key))
(custom--add-custom-loads 'binhex '(binhex))
(custom--add-custom-loads 'bookmark '(bookmark man))
(custom--add-custom-loads 'browse-url '(browse-url webjump))
(custom--add-custom-loads 'bs '(bs))
(custom--add-custom-loads 'bs-appearance '(bs))
(custom--add-custom-loads 'bubbles '(bubbles))
(custom--add-custom-loads 'bug-reference '(bug-reference))
(custom--add-custom-loads 'bytecomp '(bytecomp))
(custom--add-custom-loads 'c '(c-ts-mode cc-fonts cc-guess cc-vars cmacexp cpp csharp-mode hideif semantic/bovine/c))
(custom--add-custom-loads 'c-macro '(cmacexp))
(custom--add-custom-loads 'calc '(calc))
(custom--add-custom-loads 'calculator '(calculator))
(custom--add-custom-loads 'calendar '(appt cal-china cal-dst cal-html cal-tex cal-x calendar diary-lib holidays icalendar lunar midnight org solar todo-mode))
(custom--add-custom-loads 'calendar-chinese '(cal-china))
(custom--add-custom-loads 'calendar-dst '(cal-dst))
(custom--add-custom-loads 'calendar-faces '(calendar diary-lib))
(custom--add-custom-loads 'calendar-hooks '(cal-x calendar))
(custom--add-custom-loads 'calendar-html '(cal-html))
(custom--add-custom-loads 'calendar-tex '(cal-tex))
(custom--add-custom-loads 'canlock '(canlock))
(custom--add-custom-loads 'cedet '(cedet-cscope cedet-global cedet-idutils))
(custom--add-custom-loads 'cfengine '(cfengine))
(custom--add-custom-loads 'change-log '(add-log))
(custom--add-custom-loads 'check-declare '(check-declare))
(custom--add-custom-loads 'checkdoc '(checkdoc))
(custom--add-custom-loads 'chistory '(chistory))
(custom--add-custom-loads 'cmake '(cmake-ts-mode))
(custom--add-custom-loads 'cmuscheme '(cmuscheme))
(custom--add-custom-loads 'columns '(delim-col))
(custom--add-custom-loads 'comint '(comint))
(custom--add-custom-loads 'comint-completion '(comint))
(custom--add-custom-loads 'comm '(ange-ftp browse-url bug-reference dbus dig eudc-vars gnutls goto-addr gravatar kermit ldap net-utils nsm ntlm tramp url-vars))
(custom--add-custom-loads 'comp '(comp))
(custom--add-custom-loads 'compare-windows '(compare-w))
(custom--add-custom-loads 'compilation '(compile))
(custom--add-custom-loads 'completion '(completion))
(custom--add-custom-loads 'conf '(conf-mode))
(custom--add-custom-loads 'convenience '(autoinsert autorevert bind-key bs completion cua-base cus-edit dabbrev delim-col display-fill-column-indicator display-line-numbers emacs-lock erc-status-sidebar ffap filecache filesets follow hippie-exp hl-line ibuffer ido imenu kmacro org-protocol repeat reveal ruler-mode so-long speedbar tab-line vcursor whitespace windmove))
(custom--add-custom-loads 'cookie '(cookie1))
(custom--add-custom-loads 'copyright '(copyright))
(custom--add-custom-loads 'cperl '(cperl-mode))
(custom--add-custom-loads 'cperl-affected-by-hairy '(cperl-mode))
(custom--add-custom-loads 'cperl-autoinsert-details '(cperl-mode))
(custom--add-custom-loads 'cperl-faces '(cperl-mode))
(custom--add-custom-loads 'cperl-help-system '(cperl-mode))
(custom--add-custom-loads 'cperl-indentation-details '(cperl-mode))
(custom--add-custom-loads 'cperl-speed '(cperl-mode))
(custom--add-custom-loads 'cpp '(cpp))
(custom--add-custom-loads 'csharp '(csharp-mode))
(custom--add-custom-loads 'css '(css-mode less-css-mode))
(custom--add-custom-loads 'cua '(cua-base))
(custom--add-custom-loads 'custom-browse '(cus-edit))
(custom--add-custom-loads 'custom-buffer '(cus-edit cus-theme))
(custom--add-custom-loads 'custom-faces '(cus-edit eieio-custom))
(custom--add-custom-loads 'custom-magic-faces '(cus-edit))
(custom--add-custom-loads 'custom-menu '(cus-edit))
(custom--add-custom-loads 'customize '(cus-edit icon icons wid-edit))
(custom--add-custom-loads 'cwarn '(cwarn))
(custom--add-custom-loads 'dabbrev '(dabbrev))
(custom--add-custom-loads 'data '(arc-mode conf-mode dns-mode doc-view epg-config forms generic-x hexl remember saveplace snmp-mode sort tar-mode time-stamp timeclock))
(custom--add-custom-loads 'data-debug '(data-debug))
(custom--add-custom-loads 'dcl '(dcl-mode))
(custom--add-custom-loads 'debug '(debug))
(custom--add-custom-loads 'debugger '(debug))
(custom--add-custom-loads 'decipher '(decipher))
(custom--add-custom-loads 'desktop '(desktop))
(custom--add-custom-loads 'development '(cus-edit))
(custom--add-custom-loads 'dframe '(dframe))
(custom--add-custom-loads 'diary '(cal-hebrew calendar diary-lib))
(custom--add-custom-loads 'dictionary '(dictionary))
(custom--add-custom-loads 'dictionary-proxy '(dictionary))
(custom--add-custom-loads 'diff '(diff diff-mode smerge-mode))
(custom--add-custom-loads 'diff-mode '(diff-mode))
(custom--add-custom-loads 'dig '(dig))
(custom--add-custom-loads 'dired '(dired dired-aux dired-x find-dired ls-lisp wdired))
(custom--add-custom-loads 'dired-faces '(dired))
(custom--add-custom-loads 'dired-guess '(dired))
(custom--add-custom-loads 'dired-mark '(dired))
(custom--add-custom-loads 'dired-x '(dired-x))
(custom--add-custom-loads 'dirtrack '(dirtrack))
(custom--add-custom-loads 'display '(display-fill-column-indicator display-line-numbers face-remap glyphless-mode word-wrap-mode))
(custom--add-custom-loads 'display-line-numbers '(display-line-numbers))
(custom--add-custom-loads 'display-time '(time))
(custom--add-custom-loads 'dns-mode '(dns-mode))
(custom--add-custom-loads 'doc-view '(doc-view))
(custom--add-custom-loads 'docs '(info makeinfo texinfo))
(custom--add-custom-loads 'document '(srecode/document))
(custom--add-custom-loads 'dos-fns '(dos-vars dos-w32))
(custom--add-custom-loads 'double '(double))
(custom--add-custom-loads 'dunnet '(dunnet))
(custom--add-custom-loads 'ebnf-displacement '(ebnf2ps))
(custom--add-custom-loads 'ebnf-except '(ebnf2ps))
(custom--add-custom-loads 'ebnf-non-terminal '(ebnf2ps))
(custom--add-custom-loads 'ebnf-optimization '(ebnf2ps))
(custom--add-custom-loads 'ebnf-production '(ebnf2ps))
(custom--add-custom-loads 'ebnf-repeat '(ebnf2ps))
(custom--add-custom-loads 'ebnf-shape '(ebnf2ps))
(custom--add-custom-loads 'ebnf-special '(ebnf2ps))
(custom--add-custom-loads 'ebnf-syntactic '(ebnf2ps))
(custom--add-custom-loads 'ebnf-terminal '(ebnf2ps))
(custom--add-custom-loads 'ebnf2ps '(ebnf2ps))
(custom--add-custom-loads 'ebrowse '(ebrowse))
(custom--add-custom-loads 'ebrowse-faces '(ebrowse))
(custom--add-custom-loads 'ebrowse-member '(ebrowse))
(custom--add-custom-loads 'ebrowse-tree '(ebrowse))
(custom--add-custom-loads 'ecomplete '(ecomplete))
(custom--add-custom-loads 'ede '(ede ede/base ede/linux ede/locate ede/make ede/project-am ede/simple))
(custom--add-custom-loads 'edebug '(edebug))
(custom--add-custom-loads 'ediff '(ediff ediff-diff ediff-init ediff-mult ediff-ptch ediff-wind))
(custom--add-custom-loads 'ediff-diff '(ediff-diff))
(custom--add-custom-loads 'ediff-highlighting '(ediff-init))
(custom--add-custom-loads 'ediff-hook '(ediff-init ediff-mult))
(custom--add-custom-loads 'ediff-merge '(ediff-init ediff-merg))
(custom--add-custom-loads 'ediff-mult '(ediff-mult))
(custom--add-custom-loads 'ediff-ptch '(ediff-ptch))
(custom--add-custom-loads 'ediff-vers '(ediff-vers))
(custom--add-custom-loads 'ediff-window '(ediff-help ediff-wind))
(custom--add-custom-loads 'editing '(cus-edit misc rect))
(custom--add-custom-loads 'editing-basics '(cua-base delsel))
(custom--add-custom-loads 'edt '(edt))
(custom--add-custom-loads 'eglot '(eglot))
(custom--add-custom-loads 'eieio '(chart eieio-custom))
(custom--add-custom-loads 'electric-help '(ehelp))
(custom--add-custom-loads 'electricity '(elec-pair))
(custom--add-custom-loads 'elide-head '(elide-head))
(custom--add-custom-loads 'elint '(elint))
(custom--add-custom-loads 'elp '(elp))
(custom--add-custom-loads 'emacs '(cus-edit))
(custom--add-custom-loads 'emacs-authors-mode '(emacs-authors-mode))
(custom--add-custom-loads 'emacs-lock '(emacs-lock))
(custom--add-custom-loads 'emacs-news-mode '(emacs-news-mode))
(custom--add-custom-loads 'emacsbug '(emacsbug))
(custom--add-custom-loads 'emerge '(emerge))
(custom--add-custom-loads 'emoji '(emoji))
(custom--add-custom-loads 'emulations '(cua-base edt viper))
(custom--add-custom-loads 'enriched '(enriched))
(custom--add-custom-loads 'environment '(cus-edit dired dos-vars ebnf2ps w32-vars))
(custom--add-custom-loads 'epa '(epa epa-ks))
(custom--add-custom-loads 'epa-faces '(epa))
(custom--add-custom-loads 'epa-file '(epa-file))
(custom--add-custom-loads 'epa-ks '(epa-ks))
(custom--add-custom-loads 'epa-mail '(epa-mail))
(custom--add-custom-loads 'epg '(epa epg-config))
(custom--add-custom-loads 'erc '(erc erc-autoaway erc-button erc-capab erc-dcc erc-desktop-notifications erc-ezbounce erc-fill erc-goodies erc-ibuffer erc-identd erc-join erc-list erc-log erc-match erc-menu erc-netsplit erc-networks erc-notify erc-page erc-pcomplete erc-replace erc-ring erc-sasl erc-services erc-sound erc-speedbar erc-stamp erc-track erc-truncate))
(custom--add-custom-loads 'erc-autoaway '(erc-autoaway))
(custom--add-custom-loads 'erc-autojoin '(erc-join))
(custom--add-custom-loads 'erc-buffers '(erc))
(custom--add-custom-loads 'erc-button '(erc-button))
(custom--add-custom-loads 'erc-capab '(erc-capab))
(custom--add-custom-loads 'erc-control-characters '(erc-goodies))
(custom--add-custom-loads 'erc-dcc '(erc-dcc erc-xdcc))
(custom--add-custom-loads 'erc-display '(erc erc-goodies))
(custom--add-custom-loads 'erc-ezbounce '(erc-ezbounce))
(custom--add-custom-loads 'erc-faces '(erc erc-button erc-capab erc-goodies erc-match erc-stamp))
(custom--add-custom-loads 'erc-fill '(erc-fill))
(custom--add-custom-loads 'erc-hooks '(erc erc-netsplit))
(custom--add-custom-loads 'erc-ibuffer '(erc-ibuffer))
(custom--add-custom-loads 'erc-identd '(erc-identd))
(custom--add-custom-loads 'erc-ignore '(erc))
(custom--add-custom-loads 'erc-log '(erc-log))
(custom--add-custom-loads 'erc-lurker '(erc))
(custom--add-custom-loads 'erc-match '(erc-match))
(custom--add-custom-loads 'erc-mode-line-and-header '(erc))
(custom--add-custom-loads 'erc-netsplit '(erc-netsplit))
(custom--add-custom-loads 'erc-networks '(erc-networks))
(custom--add-custom-loads 'erc-notifications '(erc-desktop-notifications))
(custom--add-custom-loads 'erc-notify '(erc-notify))
(custom--add-custom-loads 'erc-page '(erc-page))
(custom--add-custom-loads 'erc-paranoia '(erc))
(custom--add-custom-loads 'erc-pcomplete '(erc-pcomplete))
(custom--add-custom-loads 'erc-query '(erc))
(custom--add-custom-loads 'erc-quit-and-part '(erc))
(custom--add-custom-loads 'erc-replace '(erc-replace))
(custom--add-custom-loads 'erc-sasl '(erc-sasl))
(custom--add-custom-loads 'erc-scripts '(erc))
(custom--add-custom-loads 'erc-server '(erc-backend))
(custom--add-custom-loads 'erc-server-hooks '(erc))
(custom--add-custom-loads 'erc-services '(erc-services))
(custom--add-custom-loads 'erc-sound '(erc-sound))
(custom--add-custom-loads 'erc-speedbar '(erc-speedbar))
(custom--add-custom-loads 'erc-spelling '(erc-spelling))
(custom--add-custom-loads 'erc-stamp '(erc-stamp))
(custom--add-custom-loads 'erc-status-sidebar '(erc-status-sidebar))
(custom--add-custom-loads 'erc-track '(erc-track))
(custom--add-custom-loads 'erc-truncate '(erc-truncate))
(custom--add-custom-loads 'ert '(ert))
(custom--add-custom-loads 'erts-mode '(erts-mode))
(custom--add-custom-loads 'eshell '(esh-arg esh-cmd esh-ext esh-io esh-mode esh-module esh-proc esh-util esh-var eshell))
(custom--add-custom-loads 'eshell-alias '(em-alias))
(custom--add-custom-loads 'eshell-arg '(esh-arg))
(custom--add-custom-loads 'eshell-banner '(em-banner))
(custom--add-custom-loads 'eshell-basic '(em-basic))
(custom--add-custom-loads 'eshell-cmd '(esh-cmd))
(custom--add-custom-loads 'eshell-cmpl '(em-cmpl))
(custom--add-custom-loads 'eshell-dirs '(em-dirs))
(custom--add-custom-loads 'eshell-ext '(esh-ext))
(custom--add-custom-loads 'eshell-glob '(em-glob))
(custom--add-custom-loads 'eshell-hist '(em-hist))
(custom--add-custom-loads 'eshell-io '(esh-io))
(custom--add-custom-loads 'eshell-ls '(em-ls))
(custom--add-custom-loads 'eshell-mode '(esh-mode))
(custom--add-custom-loads 'eshell-module '(em-alias em-banner em-basic em-cmpl em-dirs em-elecslash em-glob em-hist em-ls em-pred em-prompt em-rebind em-script em-smart em-term em-unix em-xtra esh-module))
(custom--add-custom-loads 'eshell-pred '(em-pred))
(custom--add-custom-loads 'eshell-proc '(esh-proc))
(custom--add-custom-loads 'eshell-prompt '(em-prompt))
(custom--add-custom-loads 'eshell-rebind '(em-rebind))
(custom--add-custom-loads 'eshell-script '(em-script))
(custom--add-custom-loads 'eshell-smart '(em-smart))
(custom--add-custom-loads 'eshell-term '(em-term))
(custom--add-custom-loads 'eshell-unix '(em-unix))
(custom--add-custom-loads 'eshell-util '(esh-util))
(custom--add-custom-loads 'eshell-var '(esh-var))
(custom--add-custom-loads 'etags '(etags speedbar))
(custom--add-custom-loads 'ethiopic '(ethio-util))
(custom--add-custom-loads 'eudc '(eudc-vars))
(custom--add-custom-loads 'eudc-bbdb '(eudc-vars))
(custom--add-custom-loads 'eudc-ldap '(eudc-vars))
(custom--add-custom-loads 'eudc-ph '(eudc-vars))
(custom--add-custom-loads 'eww '(eww))
(custom--add-custom-loads 'executable '(executable))
(custom--add-custom-loads 'expand '(expand))
(custom--add-custom-loads 'extensions '(data-debug ede ido page-ext srecode time-stamp transient wid-edit))
(custom--add-custom-loads 'external '(bib-mode browse-url cus-edit ebnf2ps epg-config locate man server))
(custom--add-custom-loads 'ezimage '(ezimage))
(custom--add-custom-loads 'f90 '(f90))
(custom--add-custom-loads 'f90-indent '(f90))
(custom--add-custom-loads 'facemenu '(facemenu))
(custom--add-custom-loads 'faces '(cus-edit cwarn dired facemenu gnus hi-lock hilit-chg message mh-e proced ps-print rcirc rst shell speedbar tab-line vtable wid-edit woman))
(custom--add-custom-loads 'feedmail '(feedmail))
(custom--add-custom-loads 'feedmail-debug '(feedmail))
(custom--add-custom-loads 'feedmail-headers '(feedmail))
(custom--add-custom-loads 'feedmail-misc '(feedmail))
(custom--add-custom-loads 'feedmail-queue '(feedmail))
(custom--add-custom-loads 'feedmail-spray '(feedmail))
(custom--add-custom-loads 'ff '(find-file))
(custom--add-custom-loads 'ffap '(ffap))
(custom--add-custom-loads 'file-cache '(filecache))
(custom--add-custom-loads 'fileloop '(fileloop))
(custom--add-custom-loads 'files '(ange-ftp autoinsert autorevert cus-edit dired filecache files-x latexenc multisession plstore recentf shadowfile tramp))
(custom--add-custom-loads 'filesets '(filesets))
(custom--add-custom-loads 'fill '(align pixel-fill))
(custom--add-custom-loads 'find-dired '(find-dired))
(custom--add-custom-loads 'find-file '(find-file))
(custom--add-custom-loads 'find-function '(find-func))
(custom--add-custom-loads 'flymake '(flymake flymake-proc))
(custom--add-custom-loads 'flymake-cc '(flymake-cc))
(custom--add-custom-loads 'flyspell '(flyspell))
(custom--add-custom-loads 'follow '(follow))
(custom--add-custom-loads 'font-lock '(hi-lock prolog))
(custom--add-custom-loads 'font-lock-highlighting-faces '(ibuffer vera-mode verilog-mode))
(custom--add-custom-loads 'footnote '(footnote))
(custom--add-custom-loads 'forms '(forms))
(custom--add-custom-loads 'fortran '(fortran))
(custom--add-custom-loads 'fortran-comment '(fortran))
(custom--add-custom-loads 'fortran-indent '(fortran))
(custom--add-custom-loads 'fortune '(fortune))
(custom--add-custom-loads 'fortune-signature '(fortune))
(custom--add-custom-loads 'frames '(desktop ediff-wind imenu two-column))
(custom--add-custom-loads 'games '(5x5 animate bubbles cookie1 decipher dunnet fortune gametree gomoku handwrite hanoi life mpuz pong solitaire spook tetris))
(custom--add-custom-loads 'gametree '(gametree))
(custom--add-custom-loads 'gdb '(gdb-mi))
(custom--add-custom-loads 'gdb-buffers '(gdb-mi))
(custom--add-custom-loads 'gdb-non-stop '(gdb-mi))
(custom--add-custom-loads 'generic-x '(generic-x))
(custom--add-custom-loads 'glasses '(glasses))
(custom--add-custom-loads 'gmm '(gmm-utils))
(custom--add-custom-loads 'gnus '(auth-source deuglify gnus gnus-art gnus-async gnus-bookmark gnus-cloud gnus-delay gnus-demon gnus-diary gnus-dup gnus-eform gnus-notifications gnus-search gnus-sieve gnus-undo gnus-uu gnus-win mail-source mm-url nnimap nnmail nnmairix nnrss nnselect nntp spam-stat))
(custom--add-custom-loads 'gnus-agent '(gnus gnus-agent))
(custom--add-custom-loads 'gnus-art '(gnus-art gnus-html))
(custom--add-custom-loads 'gnus-article '(gnus-art gnus-cite gnus-icalendar gnus-mh))
(custom--add-custom-loads 'gnus-article-buttons '(gnus-art))
(custom--add-custom-loads 'gnus-article-emphasis '(gnus-art))
(custom--add-custom-loads 'gnus-article-headers '(gnus-art gnus-fun gnus-sum))
(custom--add-custom-loads 'gnus-article-hiding '(gnus-art gnus-cite gnus-sum))
(custom--add-custom-loads 'gnus-article-highlight '(gnus-art))
(custom--add-custom-loads 'gnus-article-mime '(gnus-art gnus-sum mm-uu))
(custom--add-custom-loads 'gnus-article-saving '(gnus gnus-art))
(custom--add-custom-loads 'gnus-article-signature '(gnus-art))
(custom--add-custom-loads 'gnus-article-treat '(gnus-art))
(custom--add-custom-loads 'gnus-article-various '(gnus-art gnus-sum nnheader))
(custom--add-custom-loads 'gnus-article-washing '(gnus-art))
(custom--add-custom-loads 'gnus-asynchronous '(gnus-async))
(custom--add-custom-loads 'gnus-bookmark '(gnus-bookmark))
(custom--add-custom-loads 'gnus-cache '(gnus gnus-cache))
(custom--add-custom-loads 'gnus-charset '(gnus gnus-group gnus-sum))
(custom--add-custom-loads 'gnus-cite '(gnus-cite gnus-msg))
(custom--add-custom-loads 'gnus-cloud '(gnus-cloud))
(custom--add-custom-loads 'gnus-dbus '(gnus gnus-dbus))
(custom--add-custom-loads 'gnus-delay '(gnus-delay))
(custom--add-custom-loads 'gnus-demon '(gnus-demon))
(custom--add-custom-loads 'gnus-diary '(gnus-diary nndiary))
(custom--add-custom-loads 'gnus-dribble-file '(gnus-start))
(custom--add-custom-loads 'gnus-duplicate '(gnus-dup))
(custom--add-custom-loads 'gnus-edit-form '(gnus-eform))
(custom--add-custom-loads 'gnus-exit '(gnus gnus-group))
(custom--add-custom-loads 'gnus-extract '(gnus gnus-uu))
(custom--add-custom-loads 'gnus-extract-archive '(gnus-uu))
(custom--add-custom-loads 'gnus-extract-post '(gnus-uu))
(custom--add-custom-loads 'gnus-extract-view '(gnus-sum gnus-uu))
(custom--add-custom-loads 'gnus-files '(gnus nnmail))
(custom--add-custom-loads 'gnus-format '(gnus-spec))
(custom--add-custom-loads 'gnus-fun '(gnus-fun))
(custom--add-custom-loads 'gnus-gravatar '(gnus-gravatar))
(custom--add-custom-loads 'gnus-group '(gnus gnus-group gnus-topic))
(custom--add-custom-loads 'gnus-group-foreign '(gnus-group gnus-msg))
(custom--add-custom-loads 'gnus-group-icons '(gnus-group))
(custom--add-custom-loads 'gnus-group-levels '(gnus gnus-group gnus-start))
(custom--add-custom-loads 'gnus-group-listing '(gnus-group))
(custom--add-custom-loads 'gnus-group-new '(gnus-start))
(custom--add-custom-loads 'gnus-group-select '(gnus gnus-group gnus-sum))
(custom--add-custom-loads 'gnus-group-topic '(gnus))
(custom--add-custom-loads 'gnus-group-various '(gnus gnus-group gnus-start))
(custom--add-custom-loads 'gnus-group-visual '(gnus gnus-group))
(custom--add-custom-loads 'gnus-icalendar '(gnus-icalendar))
(custom--add-custom-loads 'gnus-icalendar-org '(gnus-icalendar))
(custom--add-custom-loads 'gnus-message '(gnus gnus-draft gnus-msg message))
(custom--add-custom-loads 'gnus-meta '(gnus gnus-util))
(custom--add-custom-loads 'gnus-newsrc '(gnus-start))
(custom--add-custom-loads 'gnus-notifications '(gnus-notifications))
(custom--add-custom-loads 'gnus-outlook-deuglify '(deuglify))
(custom--add-custom-loads 'gnus-picon '(gnus-art gnus-picon))
(custom--add-custom-loads 'gnus-registry '(gnus-registry))
(custom--add-custom-loads 'gnus-score '(gnus score-mode))
(custom--add-custom-loads 'gnus-score-adapt '(gnus gnus-score))
(custom--add-custom-loads 'gnus-score-decay '(gnus-score))
(custom--add-custom-loads 'gnus-score-default '(gnus-score gnus-sum))
(custom--add-custom-loads 'gnus-score-expire '(gnus-kill gnus-score))
(custom--add-custom-loads 'gnus-score-files '(gnus gnus-score))
(custom--add-custom-loads 'gnus-score-kill '(gnus gnus-kill))
(custom--add-custom-loads 'gnus-score-various '(gnus gnus-score))
(custom--add-custom-loads 'gnus-search '(gnus-search))
(custom--add-custom-loads 'gnus-server '(gnus gnus-int gnus-srvr nnheader))
(custom--add-custom-loads 'gnus-server-visual '(gnus-srvr))
(custom--add-custom-loads 'gnus-sieve '(gnus-sieve))
(custom--add-custom-loads 'gnus-start '(gnus gnus-group gnus-int gnus-start gnus-util nnheader))
(custom--add-custom-loads 'gnus-start-server '(gnus-start))
(custom--add-custom-loads 'gnus-summary '(gnus gnus-sum))
(custom--add-custom-loads 'gnus-summary-choose '(gnus-sum))
(custom--add-custom-loads 'gnus-summary-exit '(gnus gnus-sum))
(custom--add-custom-loads 'gnus-summary-format '(gnus gnus-diary gnus-sum))
(custom--add-custom-loads 'gnus-summary-mail '(gnus-sum))
(custom--add-custom-loads 'gnus-summary-maneuvering '(gnus-sum))
(custom--add-custom-loads 'gnus-summary-marks '(gnus gnus-sum))
(custom--add-custom-loads 'gnus-summary-pick '(gnus-salt))
(custom--add-custom-loads 'gnus-summary-sort '(gnus-sum))
(custom--add-custom-loads 'gnus-summary-tree '(gnus-salt))
(custom--add-custom-loads 'gnus-summary-various '(gnus-sum))
(custom--add-custom-loads 'gnus-summary-visual '(gnus-sum))
(custom--add-custom-loads 'gnus-thread '(gnus-group gnus-sum))
(custom--add-custom-loads 'gnus-threading '(gnus-sum))
(custom--add-custom-loads 'gnus-topic '(gnus-topic))
(custom--add-custom-loads 'gnus-undo '(gnus-undo))
(custom--add-custom-loads 'gnus-various '(gnus gnus-sum gnus-util))
(custom--add-custom-loads 'gnus-visual '(gnus gnus-art gnus-gravatar smiley))
(custom--add-custom-loads 'gnus-windows '(gnus-win))
(custom--add-custom-loads 'gnus-xmas '(gnus))
(custom--add-custom-loads 'gnutls '(gnutls))
(custom--add-custom-loads 'go '(go-ts-mode))
(custom--add-custom-loads 'gomoku '(gomoku))
(custom--add-custom-loads 'goto-address '(goto-addr))
(custom--add-custom-loads 'gravatar '(gravatar))
(custom--add-custom-loads 'grep '(grep))
(custom--add-custom-loads 'gud '(gdb-mi gud))
(custom--add-custom-loads 'handwrite '(handwrite))
(custom--add-custom-loads 'hanoi '(hanoi))
(custom--add-custom-loads 'hardware '(battery))
(custom--add-custom-loads 'hashcash '(hashcash))
(custom--add-custom-loads 'help '(apropos cus-edit ehelp help-at-pt help-fns help-macro help-mode info info-look man tutorial woman))
(custom--add-custom-loads 'help-at-pt '(help-at-pt))
(custom--add-custom-loads 'hexl '(hexl))
(custom--add-custom-loads 'hi-lock '(hi-lock))
(custom--add-custom-loads 'hi-lock-faces '(hi-lock))
(custom--add-custom-loads 'hide-ifdef '(hideif))
(custom--add-custom-loads 'hideshow '(hideshow))
(custom--add-custom-loads 'highlight-changes '(hilit-chg))
(custom--add-custom-loads 'hippie-expand '(hippie-exp))
(custom--add-custom-loads 'hl-line '(hl-line))
(custom--add-custom-loads 'holidays '(calendar holidays))
(custom--add-custom-loads 'htmlfontify '(htmlfontify))
(custom--add-custom-loads 'i18n '(cus-edit double iso-ascii latin1-disp ogonek url-vars))
(custom--add-custom-loads 'ibuffer '(ibuf-ext ibuffer))
(custom--add-custom-loads 'icalendar '(icalendar))
(custom--add-custom-loads 'icomplete '(icomplete))
(custom--add-custom-loads 'icon '(icon))
(custom--add-custom-loads 'idlwave '(idlw-help idlw-shell idlwave))
(custom--add-custom-loads 'idlwave-abbrev-and-indent-action '(idlwave))
(custom--add-custom-loads 'idlwave-code-formatting '(idlwave))
(custom--add-custom-loads 'idlwave-completion '(idlwave))
(custom--add-custom-loads 'idlwave-documentation '(idlwave))
(custom--add-custom-loads 'idlwave-external-programs '(idlwave))
(custom--add-custom-loads 'idlwave-misc '(idlwave))
(custom--add-custom-loads 'idlwave-online-help '(idlw-help))
(custom--add-custom-loads 'idlwave-routine-info '(idlwave))
(custom--add-custom-loads 'idlwave-shell-command-setup '(idlw-shell))
(custom--add-custom-loads 'idlwave-shell-general-setup '(idlw-shell idlwave))
(custom--add-custom-loads 'idlwave-shell-highlighting-and-faces '(idlw-shell))
(custom--add-custom-loads 'ido '(ido))
(custom--add-custom-loads 'ielm '(ielm))
(custom--add-custom-loads 'iimage '(iimage))
(custom--add-custom-loads 'image '(iimage image-converter image-crop image-file image-mode wallpaper))
(custom--add-custom-loads 'image-crop '(image-crop))
(custom--add-custom-loads 'image-dired '(image-dired image-dired-dired image-dired-external))
(custom--add-custom-loads 'image-dired-dired '(image-dired-dired))
(custom--add-custom-loads 'image-dired-external '(image-dired-external))
(custom--add-custom-loads 'imap '(imap))
(custom--add-custom-loads 'imenu '(imenu semantic/imenu))
(custom--add-custom-loads 'inferior-lisp '(inf-lisp))
(custom--add-custom-loads 'info '(info))
(custom--add-custom-loads 'info-lookup '(info-look))
(custom--add-custom-loads 'info-xref '(info-xref))
(custom--add-custom-loads 'initialization '(use-package-core))
(custom--add-custom-loads 'internal '(cus-edit emacs-authors-mode))
(custom--add-custom-loads 'isearch '(char-fold misearch))
(custom--add-custom-loads 'isearchb '(isearchb))
(custom--add-custom-loads 'iso-ascii '(iso-ascii))
(custom--add-custom-loads 'ispell '(flyspell ispell))
(custom--add-custom-loads 'iswitchb '(isearchb))
(custom--add-custom-loads 'java '(java-ts-mode))
(custom--add-custom-loads 'jka-compr '(jka-compr))
(custom--add-custom-loads 'js '(js))
(custom--add-custom-loads 'json '(json-ts-mode))
(custom--add-custom-loads 'kermit '(kermit))
(custom--add-custom-loads 'keyboard '(bind-key chistory keypad kmacro type-break))
(custom--add-custom-loads 'kmacro '(edmacro kmacro))
(custom--add-custom-loads 'languages '(antlr-mode asm-mode bat-mode cfengine cperl-mode css-mode cus-edit dcl-mode ethio-util f90 fortran hideshow icon idlwave info-look js ld-script m4-mode meta-mode modula2 nxml-mode octave opascal pascal perl-mode prolog ps-mode python rng-valid ruby-mode ruby-ts-mode sgml-mode sh-script sieve simula smie sql tcl vera-mode verilog-mode vhdl-mode))
(custom--add-custom-loads 'latin1-display '(latin1-disp))
(custom--add-custom-loads 'lazy-highlight '(ispell))
(custom--add-custom-loads 'ld-script '(ld-script))
(custom--add-custom-loads 'ldap '(ldap))
(custom--add-custom-loads 'leim '(indian quail))
(custom--add-custom-loads 'less-css '(less-css-mode))
(custom--add-custom-loads 'life '(life))
(custom--add-custom-loads 'lisp '(advice backtrace bytecomp checkdoc cl-indent comp edebug elp emacs-news-mode ert erts-mode find-func gmm-utils ielm inf-lisp pp profiler re-builder scheme shadow shortdoc testcover trace unsafep warnings xscheme))
(custom--add-custom-loads 'lisp-indent '(cl-indent))
(custom--add-custom-loads 'lisp-mnt '(lisp-mnt))
(custom--add-custom-loads 'lisp-shadow '(shadow))
(custom--add-custom-loads 'local '(holidays))
(custom--add-custom-loads 'locate '(locate))
(custom--add-custom-loads 'log-edit '(log-edit))
(custom--add-custom-loads 'log-view '(log-view))
(custom--add-custom-loads 'lpr '(lpr))
(custom--add-custom-loads 'ls-lisp '(ls-lisp))
(custom--add-custom-loads 'm4 '(m4-mode))
(custom--add-custom-loads 'mail '(binhex ecomplete emacsbug eudc-vars feedmail fortune gnus gnus-dired hashcash imap mail-extr mail-hist mail-utils mailalias mailclient mairix message mh-e mm-decode mspools pop3 rfc2047 rmail sendmail sieve-manage smtpmail spam spam-report supercite time uudecode))
(custom--add-custom-loads 'mail-abbrev '(mailabbrev))
(custom--add-custom-loads 'mail-extr '(mail-extr))
(custom--add-custom-loads 'mail-hist '(mail-hist))
(custom--add-custom-loads 'mail-source '(mail-source nndiary pop3))
(custom--add-custom-loads 'mailalias '(mailalias))
(custom--add-custom-loads 'mailcap '(mailcap))
(custom--add-custom-loads 'maint '(elint emacsbug lisp-mnt))
(custom--add-custom-loads 'mairix '(mairix))
(custom--add-custom-loads 'makefile '(make-mode))
(custom--add-custom-loads 'makeinfo '(makeinfo))
(custom--add-custom-loads 'man '(man))
(custom--add-custom-loads 'matching '(bookmark completion ffap imenu))
(custom--add-custom-loads 'menu '(cus-edit tmm))
(custom--add-custom-loads 'message '(footnote message mml mml-sec))
(custom--add-custom-loads 'message-buffers '(message))
(custom--add-custom-loads 'message-faces '(message))
(custom--add-custom-loads 'message-forwarding '(message))
(custom--add-custom-loads 'message-headers '(message nndraft))
(custom--add-custom-loads 'message-insertion '(message))
(custom--add-custom-loads 'message-interface '(message))
(custom--add-custom-loads 'message-mail '(message))
(custom--add-custom-loads 'message-news '(message))
(custom--add-custom-loads 'message-sending '(message))
(custom--add-custom-loads 'message-various '(message))
(custom--add-custom-loads 'meta-font '(meta-mode))
(custom--add-custom-loads 'mh-alias '(mh-alias mh-e))
(custom--add-custom-loads 'mh-e '(mh-e))
(custom--add-custom-loads 'mh-faces '(mh-e))
(custom--add-custom-loads 'mh-folder '(mh-e))
(custom--add-custom-loads 'mh-folder-selection '(mh-e))
(custom--add-custom-loads 'mh-hooks '(mh-e))
(custom--add-custom-loads 'mh-identity '(mh-e))
(custom--add-custom-loads 'mh-inc '(mh-e))
(custom--add-custom-loads 'mh-junk '(mh-e))
(custom--add-custom-loads 'mh-letter '(mh-e))
(custom--add-custom-loads 'mh-ranges '(mh-e))
(custom--add-custom-loads 'mh-scan-line-formats '(mh-e mh-scan))
(custom--add-custom-loads 'mh-search '(mh-e))
(custom--add-custom-loads 'mh-sending-mail '(mh-e))
(custom--add-custom-loads 'mh-sequences '(mh-e))
(custom--add-custom-loads 'mh-show '(mh-e))
(custom--add-custom-loads 'mh-speedbar '(mh-e))
(custom--add-custom-loads 'mh-thread '(mh-e))
(custom--add-custom-loads 'mh-tool-bar '(mh-e))
(custom--add-custom-loads 'midnight '(midnight))
(custom--add-custom-loads 'mime '(mailcap mm-bodies mm-encode mm-util rfc1843 smime))
(custom--add-custom-loads 'mime-display '(flow-fill mm-decode mm-view))
(custom--add-custom-loads 'mime-security '(gnus-art mm-decode mm-encode mml-sec mml-smime mml2015))
(custom--add-custom-loads 'minibuffer '(icomplete mb-depth minibuf-eldef savehist))
(custom--add-custom-loads 'mm-url '(mm-url))
(custom--add-custom-loads 'mode-line '(time))
(custom--add-custom-loads 'mode-line-faces '(cus-edit time))
(custom--add-custom-loads 'modula2 '(modula2))
(custom--add-custom-loads 'mouse '(artist avoid goto-addr msb pixel-scroll strokes t-mouse xt-mouse))
(custom--add-custom-loads 'mpc '(mpc))
(custom--add-custom-loads 'mpuz '(mpuz))
(custom--add-custom-loads 'msb '(msb))
(custom--add-custom-loads 'mspools '(mspools))
(custom--add-custom-loads 'mule '(descr-text kkc latexenc thai-util))
(custom--add-custom-loads 'multi-isearch '(misearch))
(custom--add-custom-loads 'multimedia '(doc-view image-dired mm-decode mpc))
(custom--add-custom-loads 'net-utils '(net-utils))
(custom--add-custom-loads 'network '(gssapi network-stream))
(custom--add-custom-loads 'news '(binhex canlock gnus message mm-decode spam spam-report supercite uudecode))
(custom--add-custom-loads 'newsticker '(newst-backend newst-reader newst-ticker))
(custom--add-custom-loads 'newsticker-faces '(newst-plainview newst-reader))
(custom--add-custom-loads 'newsticker-headline-processing '(newst-backend))
(custom--add-custom-loads 'newsticker-hooks '(newst-backend newst-plainview))
(custom--add-custom-loads 'newsticker-miscellaneous '(newst-backend))
(custom--add-custom-loads 'newsticker-plainview '(newst-plainview))
(custom--add-custom-loads 'newsticker-plainview-hooks '(newst-plainview))
(custom--add-custom-loads 'newsticker-reader '(newst-plainview newst-reader newst-treeview))
(custom--add-custom-loads 'newsticker-retrieval '(newst-backend))
(custom--add-custom-loads 'newsticker-ticker '(newst-ticker))
(custom--add-custom-loads 'newsticker-treeview '(newst-treeview))
(custom--add-custom-loads 'nndiary '(nndiary))
(custom--add-custom-loads 'nnimap '(nnimap))
(custom--add-custom-loads 'nnmail '(nnmail))
(custom--add-custom-loads 'nnmail-duplicate '(nnmail))
(custom--add-custom-loads 'nnmail-expire '(nnmail))
(custom--add-custom-loads 'nnmail-files '(nnmail))
(custom--add-custom-loads 'nnmail-prepare '(nnmail))
(custom--add-custom-loads 'nnmail-procmail '(nnmail))
(custom--add-custom-loads 'nnmail-retrieve '(nnmail))
(custom--add-custom-loads 'nnmail-split '(nndiary nnmail))
(custom--add-custom-loads 'nnmail-various '(nnmail))
(custom--add-custom-loads 'nnmairix '(nnmairix))
(custom--add-custom-loads 'nnrss '(nnrss))
(custom--add-custom-loads 'nnselect '(nnselect))
(custom--add-custom-loads 'nntp '(nntp))
(custom--add-custom-loads 'nroff '(nroff-mode))
(custom--add-custom-loads 'nsm '(nsm))
(custom--add-custom-loads 'ntlm '(ntlm))
(custom--add-custom-loads 'nxml '(nxml-mode nxml-outln rng-valid))
(custom--add-custom-loads 'nxml-faces '(nxml-mode nxml-outln))
(custom--add-custom-loads 'octave '(octave))
(custom--add-custom-loads 'ogonek '(ogonek))
(custom--add-custom-loads 'opascal '(opascal))
(custom--add-custom-loads 'org '(ob-core ol-bibtex org org-attach org-capture org-crypt org-entities org-faces org-feed org-fold-core org-footnote org-goto org-id org-indent org-mobile org-mouse org-persist org-plot org-protocol org-refile org-table org-tempo ox))
(custom--add-custom-loads 'org-agenda '(ol-bbdb org org-agenda org-compat org-duration))
(custom--add-custom-loads 'org-agenda-column-view '(org-agenda))
(custom--add-custom-loads 'org-agenda-custom-commands '(org-agenda))
(custom--add-custom-loads 'org-agenda-daily/weekly '(org org-agenda org-faces))
(custom--add-custom-loads 'org-agenda-export '(org-agenda))
(custom--add-custom-loads 'org-agenda-line-format '(org-agenda))
(custom--add-custom-loads 'org-agenda-match-view '(org-agenda))
(custom--add-custom-loads 'org-agenda-search-view '(org-agenda))
(custom--add-custom-loads 'org-agenda-skip '(org org-agenda))
(custom--add-custom-loads 'org-agenda-sorting '(org-agenda))
(custom--add-custom-loads 'org-agenda-startup '(org-agenda))
(custom--add-custom-loads 'org-agenda-time-grid '(org-agenda))
(custom--add-custom-loads 'org-agenda-todo-list '(org-agenda))
(custom--add-custom-loads 'org-agenda-windows '(org org-agenda))
(custom--add-custom-loads 'org-appearance '(org org-faces org-num))
(custom--add-custom-loads 'org-archive '(org org-archive org-cycle))
(custom--add-custom-loads 'org-attach '(org-attach org-attach-git))
(custom--add-custom-loads 'org-babel '(ob-C ob-R ob-clojure ob-core ob-ditaa ob-exp ob-fortran ob-gnuplot ob-groovy ob-haskell ob-java ob-js ob-julia ob-latex ob-lilypond ob-lisp ob-lua ob-maxima ob-ocaml ob-plantuml ob-python ob-ruby ob-scheme ob-shell ob-tangle org org-src))
(custom--add-custom-loads 'org-babel-tangle '(ob-tangle))
(custom--add-custom-loads 'org-bbdb-anniversaries '(ol-bbdb))
(custom--add-custom-loads 'org-bibtex '(ol-bibtex))
(custom--add-custom-loads 'org-capture '(org org-capture org-datetree))
(custom--add-custom-loads 'org-cite '(oc oc-basic oc-biblatex oc-csl oc-natbib))
(custom--add-custom-loads 'org-clock '(org-agenda org-clock org-duration))
(custom--add-custom-loads 'org-clocktable '(org-clock))
(custom--add-custom-loads 'org-crypt '(org-crypt))
(custom--add-custom-loads 'org-ctags '(org-ctags))
(custom--add-custom-loads 'org-cycle '(org-cycle org-list))
(custom--add-custom-loads 'org-edit-structure '(org org-fold org-src))
(custom--add-custom-loads 'org-entities '(org-entities))
(custom--add-custom-loads 'org-export '(org ox ox-ascii ox-beamer ox-html ox-icalendar ox-koma-letter ox-latex ox-man ox-md ox-odt ox-org ox-publish ox-texinfo))
(custom--add-custom-loads 'org-export-ascii '(ox-ascii))
(custom--add-custom-loads 'org-export-beamer '(ox-beamer))
(custom--add-custom-loads 'org-export-general '(ox))
(custom--add-custom-loads 'org-export-html '(org-agenda ox-html))
(custom--add-custom-loads 'org-export-icalendar '(ox-icalendar))
(custom--add-custom-loads 'org-export-koma-letter '(ox-koma-letter))
(custom--add-custom-loads 'org-export-latex '(org ox-latex ox-texinfo))
(custom--add-custom-loads 'org-export-man '(ox-man))
(custom--add-custom-loads 'org-export-md '(ox-md))
(custom--add-custom-loads 'org-export-odt '(ox-odt))
(custom--add-custom-loads 'org-export-org '(ox-org))
(custom--add-custom-loads 'org-export-publish '(org-compat ox-publish))
(custom--add-custom-loads 'org-export-texinfo '(ox-texinfo))
(custom--add-custom-loads 'org-faces '(org org-faces org-footnote org-habit org-indent org-inlinetask org-table))
(custom--add-custom-loads 'org-feed '(org-feed))
(custom--add-custom-loads 'org-fold-reveal-location '(org-fold))
(custom--add-custom-loads 'org-footnote '(org-footnote))
(custom--add-custom-loads 'org-goto '(org-goto))
(custom--add-custom-loads 'org-habit '(org-habit))
(custom--add-custom-loads 'org-id '(org org-id))
(custom--add-custom-loads 'org-imenu-and-speedbar '(org-compat))
(custom--add-custom-loads 'org-indent '(org-indent))
(custom--add-custom-loads 'org-inlinetask '(org-inlinetask))
(custom--add-custom-loads 'org-keywords '(org))
(custom--add-custom-loads 'org-latex '(org))
(custom--add-custom-loads 'org-link '(ol ol-man org-ctags))
(custom--add-custom-loads 'org-link-follow '(ol ol-doi ol-gnus ol-mhe org org-keys))
(custom--add-custom-loads 'org-link-store '(ol ol-gnus org-id))
(custom--add-custom-loads 'org-mobile '(org-mobile))
(custom--add-custom-loads 'org-mouse '(org-mouse))
(custom--add-custom-loads 'org-persist '(org-persist))
(custom--add-custom-loads 'org-plain-lists '(org-list))
(custom--add-custom-loads 'org-plot '(org-plot))
(custom--add-custom-loads 'org-priorities '(org))
(custom--add-custom-loads 'org-progress '(org org-clock org-habit org-refile))
(custom--add-custom-loads 'org-properties '(org org-colview))
(custom--add-custom-loads 'org-protocol '(org-protocol))
(custom--add-custom-loads 'org-refile '(org org-refile))
(custom--add-custom-loads 'org-sparse-trees '(org))
(custom--add-custom-loads 'org-startup '(org org-cycle org-keys))
(custom--add-custom-loads 'org-structure '(org org-compat org-cycle org-fold org-inlinetask org-keys org-list))
(custom--add-custom-loads 'org-table '(org org-table))
(custom--add-custom-loads 'org-table-calculation '(org-table))
(custom--add-custom-loads 'org-table-editing '(org-table))
(custom--add-custom-loads 'org-table-import-export '(org-table))
(custom--add-custom-loads 'org-table-settings '(org-table))
(custom--add-custom-loads 'org-tags '(org org-faces))
(custom--add-custom-loads 'org-tempo '(org-tempo))
(custom--add-custom-loads 'org-time '(org org-duration org-timer))
(custom--add-custom-loads 'org-todo '(org org-clock org-faces))
(custom--add-custom-loads 'outlines '(allout org outline))
(custom--add-custom-loads 'package '(package package-vc package-x))
(custom--add-custom-loads 'package-vc '(package-vc))
(custom--add-custom-loads 'pages '(page-ext))
(custom--add-custom-loads 'pascal '(pascal))
(custom--add-custom-loads 'password '(password-cache))
(custom--add-custom-loads 'pcl-cvs '(log-edit log-view pcvs pcvs-defs pcvs-info pcvs-parse))
(custom--add-custom-loads 'pcmpl-cvs '(pcmpl-cvs))
(custom--add-custom-loads 'pcmpl-gnu '(pcmpl-gnu))
(custom--add-custom-loads 'pcmpl-rpm '(pcmpl-rpm))
(custom--add-custom-loads 'pcmpl-unix '(pcmpl-unix))
(custom--add-custom-loads 'pcomplete '(pcmpl-cvs pcmpl-gnu pcmpl-rpm pcmpl-x pcomplete))
(custom--add-custom-loads 'perl '(perl-mode))
(custom--add-custom-loads 'pgtk '(pgtk-dnd))
(custom--add-custom-loads 'picture '(picture))
(custom--add-custom-loads 'pixel-fill '(pixel-fill))
(custom--add-custom-loads 'play '(emoji))
(custom--add-custom-loads 'plstore '(plstore))
(custom--add-custom-loads 'pong '(pong))
(custom--add-custom-loads 'pop3 '(pop3))
(custom--add-custom-loads 'postscript '(ebnf2ps printing ps-print))
(custom--add-custom-loads 'pp '(pp))
(custom--add-custom-loads 'printing '(printing))
(custom--add-custom-loads 'proced '(proced))
(custom--add-custom-loads 'proced-faces '(proced))
(custom--add-custom-loads 'processes '(ansi-color ansi-osc comint compile cus-edit executable flyspell grep gud pcomplete proced shell socks sql term))
(custom--add-custom-loads 'profiler '(profiler))
(custom--add-custom-loads 'prog-mode '(csharp-mode))
(custom--add-custom-loads 'programming '(cus-edit))
(custom--add-custom-loads 'project '(project))
(custom--add-custom-loads 'project-am '(ede/project-am))
(custom--add-custom-loads 'project-linux '(ede/linux))
(custom--add-custom-loads 'project-vc '(project))
(custom--add-custom-loads 'prolog '(prolog))
(custom--add-custom-loads 'prolog-font-lock '(prolog))
(custom--add-custom-loads 'prolog-indentation '(prolog))
(custom--add-custom-loads 'prolog-inferior '(prolog))
(custom--add-custom-loads 'prolog-keyboard '(prolog))
(custom--add-custom-loads 'prolog-other '(prolog))
(custom--add-custom-loads 'ps-print '(ps-print))
(custom--add-custom-loads 'ps-print-background '(ps-print))
(custom--add-custom-loads 'ps-print-color '(ps-print))
(custom--add-custom-loads 'ps-print-face '(ps-print))
(custom--add-custom-loads 'ps-print-font '(ps-mule ps-print))
(custom--add-custom-loads 'ps-print-headers '(ps-print))
(custom--add-custom-loads 'ps-print-horizontal '(ps-print))
(custom--add-custom-loads 'ps-print-miscellany '(ps-bdf ps-print))
(custom--add-custom-loads 'ps-print-n-up '(ps-print))
(custom--add-custom-loads 'ps-print-page '(ps-print))
(custom--add-custom-loads 'ps-print-printer '(lpr ps-print))
(custom--add-custom-loads 'ps-print-vertical '(ps-print))
(custom--add-custom-loads 'ps-print-zebra '(ps-print))
(custom--add-custom-loads 'pulse '(pulse))
(custom--add-custom-loads 'python '(python))
(custom--add-custom-loads 'python-flymake '(python))
(custom--add-custom-loads 'quail '(quail))
(custom--add-custom-loads 'rcirc '(rcirc))
(custom--add-custom-loads 'rcirc-faces '(rcirc))
(custom--add-custom-loads 're-builder '(re-builder))
(custom--add-custom-loads 'recentf '(recentf))
(custom--add-custom-loads 'recentf-filters '(recentf))
(custom--add-custom-loads 'rectangle '(rect))
(custom--add-custom-loads 'refbib '(refbib))
(custom--add-custom-loads 'refer '(refer))
(custom--add-custom-loads 'reftex '(reftex-vars))
(custom--add-custom-loads 'reftex-citation-support '(reftex-vars))
(custom--add-custom-loads 'reftex-defining-label-environments '(reftex-vars))
(custom--add-custom-loads 'reftex-finding-files '(reftex-vars))
(custom--add-custom-loads 'reftex-fontification-configurations '(reftex-vars))
(custom--add-custom-loads 'reftex-index-support '(reftex-vars))
(custom--add-custom-loads 'reftex-label-support '(reftex-vars))
(custom--add-custom-loads 'reftex-making-and-inserting-labels '(reftex-vars))
(custom--add-custom-loads 'reftex-miscellaneous-configurations '(reftex-vars))
(custom--add-custom-loads 'reftex-optimizations-for-large-documents '(reftex-vars))
(custom--add-custom-loads 'reftex-referencing-labels '(reftex-vars))
(custom--add-custom-loads 'reftex-table-of-contents-browser '(reftex-vars))
(custom--add-custom-loads 'reftex-viewing-cross-references '(reftex-vars))
(custom--add-custom-loads 'relax-ng '(rng-loc rng-nxml rng-valid))
(custom--add-custom-loads 'remember '(remember))
(custom--add-custom-loads 'repeat '(repeat))
(custom--add-custom-loads 'reveal '(reveal))
(custom--add-custom-loads 'rfc2047 '(rfc2047))
(custom--add-custom-loads 'rmail '(rmail rmail-spam-filter rmailmm))
(custom--add-custom-loads 'rmail-edit '(rmail rmailedit))
(custom--add-custom-loads 'rmail-files '(rmail unrmail))
(custom--add-custom-loads 'rmail-headers '(rmail undigest))
(custom--add-custom-loads 'rmail-mime '(rmailmm))
(custom--add-custom-loads 'rmail-output '(rmailout))
(custom--add-custom-loads 'rmail-reply '(rmail))
(custom--add-custom-loads 'rmail-retrieve '(rmail))
(custom--add-custom-loads 'rmail-spam-filter '(rmail-spam-filter))
(custom--add-custom-loads 'rmail-summary '(rmail rmailsum))
(custom--add-custom-loads 'rst '(rst))
(custom--add-custom-loads 'rst-adjust '(rst))
(custom--add-custom-loads 'rst-compile '(rst))
(custom--add-custom-loads 'rst-faces '(rst))
(custom--add-custom-loads 'rst-indent '(rst))
(custom--add-custom-loads 'rst-toc '(rst))
(custom--add-custom-loads 'ruby '(ruby-mode))
(custom--add-custom-loads 'ruler-mode '(ruler-mode))
(custom--add-custom-loads 'rust '(rust-ts-mode))
(custom--add-custom-loads 'save-place '(saveplace))
(custom--add-custom-loads 'savehist '(savehist))
(custom--add-custom-loads 'scheme '(cmuscheme scheme))
(custom--add-custom-loads 'scrolling '(pixel-scroll))
(custom--add-custom-loads 'security '(textsec-check))
(custom--add-custom-loads 'semantic '(semantic semantic/analyze semantic/bovine/c semantic/bovine/el semantic/complete semantic/db semantic/db-mode semantic/decorate/mode semantic/edit semantic/format semantic/grammar semantic/ia semantic/idle semantic/imenu semantic/lex semantic/lex-spp semantic/mru-bookmark semantic/senator semantic/symref semantic/symref/grep semantic/symref/list semantic/util-modes semantic/wisent/wisent))
(custom--add-custom-loads 'semantic-faces '(semantic/complete semantic/decorate/include semantic/decorate/mode semantic/idle semantic/senator semantic/util-modes srecode/fields))
(custom--add-custom-loads 'semantic-imenu '(semantic/imenu))
(custom--add-custom-loads 'semantic-modes '(semantic/decorate/mode semantic/idle semantic/mru-bookmark semantic/util-modes))
(custom--add-custom-loads 'semantic-symref-results-mode '(semantic/symref/list))
(custom--add-custom-loads 'semanticdb '(semantic/db semantic/db-ebrowse semantic/db-file semantic/db-find))
(custom--add-custom-loads 'senator '(semantic/senator))
(custom--add-custom-loads 'sendmail '(sendmail))
(custom--add-custom-loads 'server '(server))
(custom--add-custom-loads 'ses '(ses))
(custom--add-custom-loads 'sgml '(mhtml-mode sgml-mode))
(custom--add-custom-loads 'sh '(sh-script))
(custom--add-custom-loads 'sh-indentation '(sh-script))
(custom--add-custom-loads 'sh-script '(sh-script))
(custom--add-custom-loads 'shadow '(shadowfile))
(custom--add-custom-loads 'shell '(dirtrack shell))
(custom--add-custom-loads 'shell-directories '(shell))
(custom--add-custom-loads 'shortdoc '(shortdoc))
(custom--add-custom-loads 'shr '(shr shr-color))
(custom--add-custom-loads 'shr-color '(shr-color))
(custom--add-custom-loads 'sieve '(sieve sieve-mode))
(custom--add-custom-loads 'sieve-manage '(sieve-manage))
(custom--add-custom-loads 'simula '(simula))
(custom--add-custom-loads 'smerge '(smerge-mode))
(custom--add-custom-loads 'smie '(smie))
(custom--add-custom-loads 'smiley '(smiley))
(custom--add-custom-loads 'smime '(smime))
(custom--add-custom-loads 'smtpmail '(smtpmail))
(custom--add-custom-loads 'snmp '(snmp-mode))
(custom--add-custom-loads 'so-long '(so-long))
(custom--add-custom-loads 'soap-client '(soap-client))
(custom--add-custom-loads 'socks '(socks))
(custom--add-custom-loads 'solitaire '(solitaire))
(custom--add-custom-loads 'sort '(sort))
(custom--add-custom-loads 'spam '(spam))
(custom--add-custom-loads 'spam-bogofilter '(spam))
(custom--add-custom-loads 'spam-bsfilter '(spam))
(custom--add-custom-loads 'spam-crm114 '(spam))
(custom--add-custom-loads 'spam-ifile '(spam))
(custom--add-custom-loads 'spam-report '(spam-report))
(custom--add-custom-loads 'spam-spamassassin '(spam))
(custom--add-custom-loads 'spam-spamoracle '(spam))
(custom--add-custom-loads 'spam-stat '(spam-stat))
(custom--add-custom-loads 'speedbar '(rmail semantic/sb speedbar))
(custom--add-custom-loads 'speedbar-faces '(speedbar vhdl-mode))
(custom--add-custom-loads 'speedbar-vc '(speedbar))
(custom--add-custom-loads 'spook '(spook))
(custom--add-custom-loads 'srecode '(srecode/cpp srecode/document srecode/expandproto srecode/fields srecode/insert srecode/map srecode/mode srecode/srt-mode))
(custom--add-custom-loads 'srecode-cpp '(srecode/cpp))
(custom--add-custom-loads 'strokes '(strokes))
(custom--add-custom-loads 'supercite '(supercite))
(custom--add-custom-loads 'supercite-attr '(supercite))
(custom--add-custom-loads 'supercite-cite '(supercite))
(custom--add-custom-loads 'supercite-frames '(supercite))
(custom--add-custom-loads 'supercite-hooks '(supercite))
(custom--add-custom-loads 'tab-line '(tab-line))
(custom--add-custom-loads 'tab-line-faces '(tab-line))
(custom--add-custom-loads 'table '(table))
(custom--add-custom-loads 'table-hooks '(table))
(custom--add-custom-loads 'tamil-input '(indian))
(custom--add-custom-loads 'tar '(tar-mode))
(custom--add-custom-loads 'tcl '(tcl))
(custom--add-custom-loads 'tempo '(tempo))
(custom--add-custom-loads 'term '(term))
(custom--add-custom-loads 'testcover '(testcover))
(custom--add-custom-loads 'tetris '(tetris))
(custom--add-custom-loads 'tex '(bibtex reftex-vars tex-mode))
(custom--add-custom-loads 'tex-file '(tex-mode))
(custom--add-custom-loads 'tex-flymake '(tex-mode))
(custom--add-custom-loads 'tex-run '(tex-mode))
(custom--add-custom-loads 'tex-view '(tex-mode))
(custom--add-custom-loads 'texinfo '(informat srecode/document texinfo))
(custom--add-custom-loads 'text '(bib-mode cus-edit delim-col ebnf2ps enriched lpr nroff-mode outline picture printing ps-print refbib refer rng-valid rst string-edit table tildify view))
(custom--add-custom-loads 'textsec '(textsec-check))
(custom--add-custom-loads 'thread-list '(thread))
(custom--add-custom-loads 'tildify '(tildify))
(custom--add-custom-loads 'time-stamp '(time-stamp))
(custom--add-custom-loads 'timeclock '(timeclock))
(custom--add-custom-loads 'tmm '(tmm))
(custom--add-custom-loads 'todo '(todo-mode))
(custom--add-custom-loads 'todo-categories '(todo-mode))
(custom--add-custom-loads 'todo-display '(todo-mode))
(custom--add-custom-loads 'todo-edit '(todo-mode))
(custom--add-custom-loads 'todo-faces '(todo-mode))
(custom--add-custom-loads 'todo-filtered '(todo-mode))
(custom--add-custom-loads 'toml '(toml-ts-mode))
(custom--add-custom-loads 'tools '(add-log calculator check-declare cl-font-lock cl-lib compare-w compile copyright diff diff-mode ebrowse ede ede/linux ede/project-am ediff elide-head emerge etags fileloop flymake gdb-mi glasses grep gud make-mode pcvs-defs project semantic sieve smerge-mode soap-client speedbar srecode tempo treesit vc which-func xref))
(custom--add-custom-loads 'tooltip '(gud))
(custom--add-custom-loads 'trace '(trace))
(custom--add-custom-loads 'tramp '(files-x tramp tramp-adb tramp-cache tramp-cmds tramp-container tramp-crypt tramp-fuse tramp-gvfs tramp-rclone tramp-sh tramp-smb tramp-sshfs))
(custom--add-custom-loads 'transient '(transient))
(custom--add-custom-loads 'transient-color-faces '(transient))
(custom--add-custom-loads 'transient-faces '(transient))
(custom--add-custom-loads 'tree-widget '(tree-widget))
(custom--add-custom-loads 'treesit '(treesit))
(custom--add-custom-loads 'two-column '(two-column))
(custom--add-custom-loads 'type-break '(type-break))
(custom--add-custom-loads 'typescript '(typescript-ts-mode))
(custom--add-custom-loads 'unix '(proced shell))
(custom--add-custom-loads 'url '(url url-cookie url-gw url-handlers url-history url-irc url-nfs url-queue url-tramp url-vars))
(custom--add-custom-loads 'url-cache '(url-cache url-vars))
(custom--add-custom-loads 'url-cookie '(url-cookie))
(custom--add-custom-loads 'url-file '(url-cache url-cookie url-vars))
(custom--add-custom-loads 'url-gateway '(url-gw))
(custom--add-custom-loads 'url-hairy '(url-util url-vars))
(custom--add-custom-loads 'url-history '(url-history))
(custom--add-custom-loads 'url-mime '(url-vars))
(custom--add-custom-loads 'use-package '(use-package-core use-package-ensure))
(custom--add-custom-loads 'use-package-ensure '(use-package-ensure))
(custom--add-custom-loads 'uudecode '(uudecode))
(custom--add-custom-loads 'vc '(log-edit vc vc-annotate vc-bzr vc-cvs vc-dir vc-dispatcher vc-git vc-hg vc-rcs vc-sccs vc-src vc-svn))
(custom--add-custom-loads 'vc-bzr '(vc-bzr))
(custom--add-custom-loads 'vc-cvs '(vc-cvs))
(custom--add-custom-loads 'vc-git '(vc-git))
(custom--add-custom-loads 'vc-hg '(vc-hg))
(custom--add-custom-loads 'vc-rcs '(vc-rcs))
(custom--add-custom-loads 'vc-sccs '(vc-sccs))
(custom--add-custom-loads 'vc-src '(vc-src))
(custom--add-custom-loads 'vc-svn '(vc-svn))
(custom--add-custom-loads 'vcursor '(vcursor))
(custom--add-custom-loads 'vera '(vera-mode))
(custom--add-custom-loads 'verilog-mode '(verilog-mode))
(custom--add-custom-loads 'verilog-mode-actions '(verilog-mode))
(custom--add-custom-loads 'verilog-mode-auto '(verilog-mode))
(custom--add-custom-loads 'verilog-mode-indent '(verilog-mode))
(custom--add-custom-loads 'vhdl '(vhdl-mode))
(custom--add-custom-loads 'vhdl-beautify '(vhdl-mode))
(custom--add-custom-loads 'vhdl-comment '(vhdl-mode))
(custom--add-custom-loads 'vhdl-compile '(vhdl-mode))
(custom--add-custom-loads 'vhdl-compose '(vhdl-mode))
(custom--add-custom-loads 'vhdl-header '(vhdl-mode))
(custom--add-custom-loads 'vhdl-highlight '(vhdl-mode))
(custom--add-custom-loads 'vhdl-highlight-faces '(vhdl-mode))
(custom--add-custom-loads 'vhdl-menu '(vhdl-mode))
(custom--add-custom-loads 'vhdl-misc '(vhdl-mode))
(custom--add-custom-loads 'vhdl-mode '(vhdl-mode))
(custom--add-custom-loads 'vhdl-model '(vhdl-mode))
(custom--add-custom-loads 'vhdl-naming '(vhdl-mode))
(custom--add-custom-loads 'vhdl-port '(vhdl-mode))
(custom--add-custom-loads 'vhdl-print '(vhdl-mode))
(custom--add-custom-loads 'vhdl-project '(vhdl-mode))
(custom--add-custom-loads 'vhdl-sequential-process '(vhdl-mode))
(custom--add-custom-loads 'vhdl-speedbar '(vhdl-mode))
(custom--add-custom-loads 'vhdl-style '(vhdl-mode))
(custom--add-custom-loads 'vhdl-template '(vhdl-mode))
(custom--add-custom-loads 'vhdl-testbench '(vhdl-mode))
(custom--add-custom-loads 'view '(calendar view))
(custom--add-custom-loads 'viper '(viper viper-ex viper-init viper-keym viper-macs viper-mous viper-util))
(custom--add-custom-loads 'viper-ex '(viper-ex))
(custom--add-custom-loads 'viper-highlighting '(viper-init))
(custom--add-custom-loads 'viper-hooks '(viper-init))
(custom--add-custom-loads 'viper-misc '(viper viper-cmd viper-init))
(custom--add-custom-loads 'viper-mouse '(viper-mous))
(custom--add-custom-loads 'viper-search '(viper-init))
(custom--add-custom-loads 'w32 '(dos-w32 w32-vars))
(custom--add-custom-loads 'warnings '(warnings))
(custom--add-custom-loads 'wdired '(wdired))
(custom--add-custom-loads 'web '(eww shr xwidget))
(custom--add-custom-loads 'webjump '(webjump))
(custom--add-custom-loads 'which-func '(which-func))
(custom--add-custom-loads 'whitespace '(whitespace))
(custom--add-custom-loads 'widget-browse '(wid-browse))
(custom--add-custom-loads 'widget-button '(wid-edit))
(custom--add-custom-loads 'widget-documentation '(wid-edit))
(custom--add-custom-loads 'widget-faces '(wid-edit))
(custom--add-custom-loads 'widgets '(tree-widget wid-browse wid-edit xwidget))
(custom--add-custom-loads 'windmove '(windmove))
(custom--add-custom-loads 'windows '(follow scroll-all windmove winner))
(custom--add-custom-loads 'winner '(winner))
(custom--add-custom-loads 'wisent '(semantic/wisent/comp semantic/wisent/wisent))
(custom--add-custom-loads 'woman '(woman))
(custom--add-custom-loads 'woman-faces '(woman))
(custom--add-custom-loads 'woman-formatting '(woman))
(custom--add-custom-loads 'woman-interface '(woman))
(custom--add-custom-loads 'world-clock '(time))
(custom--add-custom-loads 'wp '(cus-edit))
(custom--add-custom-loads 'xref '(find-func xref))
(custom--add-custom-loads 'xscheme '(xscheme))
(custom--add-custom-loads 'xterm '(xt-mouse))
(custom--add-custom-loads 'xwidget-webkit '(xwidget))

;; The remainder of this file is for handling :version.
;; We provide a minimum of information so that `customize-changed'
;; can do its job.

;; For groups we set `custom-version', `group-documentation' and
;; `custom-tag' (which are shown in the customize buffer), so we
;; don't have to load the file containing the group.

;; This macro is used so we don't modify the information about
;; variables and groups if it's already set. (We don't know when
;; cus-load.el is going to be loaded and at that time some of the
;; files might be loaded and some others might not).
(defmacro custom-put-if-not (symbol propname value)
  `(unless (get ,symbol ,propname)
     (put ,symbol ,propname ,value)))

(custom-put-if-not 'SQL 'custom-version '"20.4")
(custom-put-if-not 'SQL 'group-documentation "Running a SQL interpreter from within Emacs buffers.")
(custom-put-if-not 'align 'custom-version '"21.1")
(custom-put-if-not 'align 'group-documentation "Align text to a specific column, by regexp.")
(custom-put-if-not 'ansi-colors 'custom-version '"21.1")
(custom-put-if-not 'ansi-colors 'group-documentation "Translating SGR control sequences to faces.
This translation effectively colorizes strings and regions based upon
SGR control sequences embedded in the text.  SGR (Select Graphic
Rendition) control sequences are defined in section 8.3.117 of the
ECMA-48 standard (identical to ISO/IEC 6429), which is freely available
at <URL:https://www.ecma-international.org/publications/standards/Ecma-048.htm>
as a PDF file.")
(custom-put-if-not 'ansi-osc 'custom-version '"29.1")
(custom-put-if-not 'ansi-osc 'group-documentation "Interpretation of OSC escape sequences.
Handlers for OSC 2, 7 and 8 (for window title, current directory
and hyperlinks respectively) are provided.  OSC (Operating System
Commands) control sequences are defined in section 8.3.89 of the
ECMA-48 standard is freely available at
<URL:https://www.ecma-international.org/publications/standards/Ecma-048.htm>
as a PDF file.")
(custom-put-if-not 'auth-source 'custom-version '"23.1")
(custom-put-if-not 'auth-source 'group-documentation "Authentication sources.")
(custom-put-if-not 'auth-source-pass 'custom-version '"27.1")
(custom-put-if-not 'auth-source-pass 'group-documentation "password-store integration within auth-source.")
(custom-put-if-not 'bind-key 'custom-version '"29.1")
(custom-put-if-not 'bind-key 'group-documentation "A simple way to manage personal keybindings.")
(custom-put-if-not 'bs 'custom-version '"21.1")
(custom-put-if-not 'bs 'group-documentation "Buffer Selection: Maintaining buffers by buffer menu.")
(custom-put-if-not 'calculator 'custom-version '"21.1")
(custom-put-if-not 'calculator 'group-documentation "Simple Emacs calculator.")
(custom-put-if-not 'checkdoc 'custom-version '"20.3")
(custom-put-if-not 'checkdoc 'group-documentation "Support for doc string checking in Emacs Lisp.")
(custom-put-if-not 'conf 'custom-version '"22.1")
(custom-put-if-not 'conf 'group-documentation "Configuration files.")
(custom-put-if-not 'cperl 'custom-version '"20.3")
(custom-put-if-not 'cperl 'group-documentation "Major mode for editing Perl code.")
(custom-put-if-not 'cua 'custom-version '"22.1")
(custom-put-if-not 'cua 'group-documentation "Emulate CUA key bindings including C-x and C-c.")
(custom-put-if-not 'cwarn 'custom-version '"21.1")
(custom-put-if-not 'cwarn 'group-documentation "Highlight suspicious C and C++ constructions.")
(custom-put-if-not 'dbus 'custom-version '"28.1")
(custom-put-if-not 'dbus 'group-documentation "Elisp bindings for D-Bus.")
(custom-put-if-not 'diff-mode 'custom-version '"21.1")
(custom-put-if-not 'diff-mode 'group-documentation "Major mode for viewing/editing diffs.")
(custom-put-if-not 'doc-view 'custom-version '"22.2")
(custom-put-if-not 'doc-view 'group-documentation "In-buffer document viewer.
The viewer handles PDF, PostScript, DVI, DJVU, ODF, EPUB, CBZ,
FB2, XPS and OXPS files, if the appropriate converter programs
are available (see Info node `(emacs)Document View').")
(custom-put-if-not 'ebnf-displacement 'custom-version '"20")
(custom-put-if-not 'ebnf-displacement 'group-documentation "Displacement customization.")
(custom-put-if-not 'ebnf-displacement 'custom-tag "Displacement")
(custom-put-if-not 'ebnf-except 'custom-version '"20")
(custom-put-if-not 'ebnf-except 'group-documentation "Except customization.")
(custom-put-if-not 'ebnf-except 'custom-tag "Except")
(custom-put-if-not 'ebnf-non-terminal 'custom-version '"20")
(custom-put-if-not 'ebnf-non-terminal 'group-documentation "Non-Terminal customization.")
(custom-put-if-not 'ebnf-non-terminal 'custom-tag "Non-Terminal")
(custom-put-if-not 'ebnf-optimization 'custom-version '"20")
(custom-put-if-not 'ebnf-optimization 'group-documentation "Optimization customization.")
(custom-put-if-not 'ebnf-optimization 'custom-tag "Optimization")
(custom-put-if-not 'ebnf-production 'custom-version '"20")
(custom-put-if-not 'ebnf-production 'group-documentation "Production customization.")
(custom-put-if-not 'ebnf-production 'custom-tag "Production")
(custom-put-if-not 'ebnf-repeat 'custom-version '"20")
(custom-put-if-not 'ebnf-repeat 'group-documentation "Repeat customization.")
(custom-put-if-not 'ebnf-repeat 'custom-tag "Repeat")
(custom-put-if-not 'ebnf-shape 'custom-version '"20")
(custom-put-if-not 'ebnf-shape 'group-documentation "Shapes customization.")
(custom-put-if-not 'ebnf-shape 'custom-tag "Shape")
(custom-put-if-not 'ebnf-special 'custom-version '"20")
(custom-put-if-not 'ebnf-special 'group-documentation "Special customization.")
(custom-put-if-not 'ebnf-special 'custom-tag "Special")
(custom-put-if-not 'ebnf-syntactic 'custom-version '"20")
(custom-put-if-not 'ebnf-syntactic 'group-documentation "Syntactic customization.")
(custom-put-if-not 'ebnf-syntactic 'custom-tag "Syntactic")
(custom-put-if-not 'ebnf-terminal 'custom-version '"20")
(custom-put-if-not 'ebnf-terminal 'group-documentation "Terminal customization.")
(custom-put-if-not 'ebnf-terminal 'custom-tag "Terminal")
(custom-put-if-not 'ebnf2ps 'custom-version '"20")
(custom-put-if-not 'ebnf2ps 'group-documentation "Translate an EBNF to a syntactic chart on PostScript.")
(custom-put-if-not 'electric-help 'custom-version '"21.1")
(custom-put-if-not 'electric-help 'group-documentation "Electric help facility.")
(custom-put-if-not 'elide-head 'custom-version '"21.1")
(custom-put-if-not 'elide-head 'group-documentation "Eliding copyright headers and the like in source files.")
(custom-put-if-not 'emacs-authors-mode 'custom-version '"29.1")
(custom-put-if-not 'emacs-authors-mode 'group-documentation "Display the \"etc/AUTHORS\" file from the Emacs distribution.")
(custom-put-if-not 'emacs-lock 'custom-version '"24.1")
(custom-put-if-not 'emacs-lock 'group-documentation "Emacs-Lock mode.")
(custom-put-if-not 'epa 'custom-version '"23.1")
(custom-put-if-not 'epa 'group-documentation "The EasyPG Assistant.")
(custom-put-if-not 'epa-faces 'custom-version '"23.1")
(custom-put-if-not 'epa-faces 'group-documentation "Faces for epa-mode.")
(custom-put-if-not 'epa-ks 'custom-version '"28.1")
(custom-put-if-not 'epa-ks 'group-documentation "The EasyPG Assistant Keyserver client.")
(custom-put-if-not 'epg 'custom-version '"23.1")
(custom-put-if-not 'epg 'group-documentation "Interface to the GNU Privacy Guard (GnuPG).")
(custom-put-if-not 'epg 'custom-tag "EasyPG")
(custom-put-if-not 'erc-lurker 'custom-version '"24.3")
(custom-put-if-not 'erc-lurker 'group-documentation "Hide specified message types sent by lurkers.")
(custom-put-if-not 'erc-notifications 'custom-version '"24.3")
(custom-put-if-not 'erc-notifications 'group-documentation "Send notifications on PRIVMSG or mentions.")
(custom-put-if-not 'eshell 'custom-version '"21.1")
(custom-put-if-not 'eshell 'group-documentation "Command shell implemented entirely in Emacs Lisp.
It invokes no external processes beyond those requested by the
user, and is intended to be a functional replacement for command
shells such as bash, zsh, rc, 4dos.")
(custom-put-if-not 'ethiopic 'custom-version '"28.1")
(custom-put-if-not 'ethiopic 'group-documentation "Options for writing Ethiopic.")
(custom-put-if-not 'eudc 'custom-version '"21.1")
(custom-put-if-not 'eudc 'group-documentation "Emacs Unified Directory Client.")
(custom-put-if-not 'eww 'custom-version '"25.1")
(custom-put-if-not 'eww 'group-documentation "Emacs Web Wowser.")
(custom-put-if-not 'filesets 'custom-version '"22.1")
(custom-put-if-not 'filesets 'group-documentation "The fileset swapper.")
(custom-put-if-not 'flymake 'custom-version '"23.1")
(custom-put-if-not 'flymake 'group-documentation "Universal on-the-fly syntax checker.")
(custom-put-if-not 'footnote 'custom-version '"21.1")
(custom-put-if-not 'footnote 'group-documentation "Support for footnotes in mail and news messages.")
(custom-put-if-not 'fortune 'custom-version '"21.1")
(custom-put-if-not 'fortune 'group-documentation "Settings for fortune.")
(custom-put-if-not 'gametree 'custom-version '"20.3")
(custom-put-if-not 'gametree 'group-documentation "Manage game analysis trees in Emacs.")
(custom-put-if-not 'gdb 'custom-version '"23.2")
(custom-put-if-not 'gdb 'group-documentation "GDB graphical interface.")
(custom-put-if-not 'gdb-buffers 'custom-version '"23.2")
(custom-put-if-not 'gdb-buffers 'group-documentation "GDB buffers.")
(custom-put-if-not 'gdb-non-stop 'custom-version '"23.2")
(custom-put-if-not 'gdb-non-stop 'group-documentation "GDB non-stop debugging settings.")
(custom-put-if-not 'generic-x 'custom-version '"20.3")
(custom-put-if-not 'generic-x 'group-documentation "A collection of generic modes.")
(custom-put-if-not 'glasses 'custom-version '"21.1")
(custom-put-if-not 'glasses 'group-documentation "Make unreadable code likeThis(one) readable.")
(custom-put-if-not 'gmm 'custom-version '"22.1")
(custom-put-if-not 'gmm 'group-documentation "Utility functions for Gnus, Message and MML.")
(custom-put-if-not 'gnus-charset 'custom-version '"21.1")
(custom-put-if-not 'gnus-charset 'group-documentation "Group character set issues.")
(custom-put-if-not 'gnus-cloud 'custom-version '"25.1")
(custom-put-if-not 'gnus-cloud 'group-documentation "Syncing Gnus data via IMAP.")
(custom-put-if-not 'gnus-delay 'custom-version '"22.1")
(custom-put-if-not 'gnus-delay 'group-documentation "Arrange for sending postings later.")
(custom-put-if-not 'gnus-diary 'custom-version '"22.1")
(custom-put-if-not 'gnus-diary 'group-documentation "Utilities on top of the nndiary back end for Gnus.")
(custom-put-if-not 'gnus-icalendar 'custom-version '"24.4")
(custom-put-if-not 'gnus-icalendar 'group-documentation "Settings for inline display of iCalendar invitations.")
(custom-put-if-not 'gnus-icalendar-org 'custom-version '"24.4")
(custom-put-if-not 'gnus-icalendar-org 'group-documentation "Settings for Calendar Event gnus/org integration.")
(custom-put-if-not 'gnus-notifications 'custom-version '"24.3")
(custom-put-if-not 'gnus-notifications 'group-documentation "Send notifications on new message in Gnus.")
(custom-put-if-not 'gnus-outlook-deuglify 'custom-version '"22.1")
(custom-put-if-not 'gnus-outlook-deuglify 'group-documentation "Deuglify articles generated by broken user agents like MS Outlook (Express).")
(custom-put-if-not 'gnus-registry 'custom-version '"22.1")
(custom-put-if-not 'gnus-registry 'group-documentation "Article Registry.")
(custom-put-if-not 'gnutls 'custom-version '"24.1")
(custom-put-if-not 'gnutls 'group-documentation "Emacs interface to the GnuTLS library.")
(custom-put-if-not 'gravatar 'custom-version '"24.1")
(custom-put-if-not 'gravatar 'group-documentation "Gravatars.")
(custom-put-if-not 'help-at-pt 'custom-version '"22.1")
(custom-put-if-not 'help-at-pt 'group-documentation "Features for displaying local help.")
(custom-put-if-not 'ibuffer 'custom-version '"22.1")
(custom-put-if-not 'ibuffer 'group-documentation "Advanced replacement for `buffer-menu'.
Ibuffer lets you operate on buffers in a Dired-like way,
with the ability to sort, mark by regular expression,
and filter displayed buffers by various criteria.")
(custom-put-if-not 'ido 'custom-version '"22.1")
(custom-put-if-not 'ido 'group-documentation "Switch between files using substrings.")
(custom-put-if-not 'iimage 'custom-version '"22.1")
(custom-put-if-not 'iimage 'group-documentation "Support for inline images.")
(custom-put-if-not 'imap 'custom-version '"21.1")
(custom-put-if-not 'imap 'group-documentation "Low-level IMAP issues.")
(custom-put-if-not 'inferior-lisp 'custom-version '"22.1")
(custom-put-if-not 'inferior-lisp 'group-documentation "Run an outside Lisp in an Emacs buffer.")
(custom-put-if-not 'kmacro 'custom-version '"22.1")
(custom-put-if-not 'kmacro 'group-documentation "Simplified keyboard macro user interface.")
(custom-put-if-not 'ldap 'custom-version '"21.1")
(custom-put-if-not 'ldap 'group-documentation "Lightweight Directory Access Protocol.")
(custom-put-if-not 'less-css 'custom-version '"26.1")
(custom-put-if-not 'less-css 'group-documentation "Less CSS mode.")
(custom-put-if-not 'log-edit 'custom-version '"21.1")
(custom-put-if-not 'log-edit 'group-documentation "Major mode for editing RCS and CVS commit messages.")
(custom-put-if-not 'ls-lisp 'custom-version '"21.1")
(custom-put-if-not 'ls-lisp 'group-documentation "Emulate the ls program completely in Emacs Lisp.")
(custom-put-if-not 'mail-source 'custom-version '"21.1")
(custom-put-if-not 'mail-source 'group-documentation "The mail-fetching library.")
(custom-put-if-not 'mailcap 'custom-version '"21.1")
(custom-put-if-not 'mailcap 'group-documentation "Definition of viewers for MIME types.")
(custom-put-if-not 'midnight 'custom-version '"20.3")
(custom-put-if-not 'midnight 'group-documentation "Run something every day at midnight.")
(custom-put-if-not 'mime-display 'custom-version '"21.1")
(custom-put-if-not 'mime-display 'group-documentation "Display of MIME in mail and news articles.")
(custom-put-if-not 'multi-isearch 'custom-version '"23.1")
(custom-put-if-not 'multi-isearch 'group-documentation "Using isearch to search through multiple buffers.")
(custom-put-if-not 'net-utils 'custom-version '"20.3")
(custom-put-if-not 'net-utils 'group-documentation "Network utility functions.")
(custom-put-if-not 'nndiary 'custom-version '"22.1")
(custom-put-if-not 'nndiary 'group-documentation "The Gnus Diary back end.")
(custom-put-if-not 'nsm 'custom-version '"25.1")
(custom-put-if-not 'nsm 'group-documentation "Network Security Manager.")
(custom-put-if-not 'ntlm 'custom-version '"25.1")
(custom-put-if-not 'ntlm 'group-documentation "NTLM (NT LanManager) authentication.")
(custom-put-if-not 'opascal 'custom-version '"24.4")
(custom-put-if-not 'opascal 'group-documentation "Major mode for editing OPascal source in Emacs.")
(custom-put-if-not 'org-export-beamer 'custom-version '"24.2")
(custom-put-if-not 'org-export-beamer 'group-documentation "Options specific for using the beamer class in LaTeX export.")
(custom-put-if-not 'org-export-beamer 'custom-tag "Org Beamer")
(custom-put-if-not 'org-export-md 'custom-version '"24.4")
(custom-put-if-not 'org-export-md 'group-documentation "Options specific to Markdown export back-end.")
(custom-put-if-not 'org-export-md 'custom-tag "Org Markdown")
(custom-put-if-not 'org-export-org 'custom-version '"24.4")
(custom-put-if-not 'org-export-org 'group-documentation "Options for exporting Org mode files to Org.")
(custom-put-if-not 'org-export-org 'custom-tag "Org Export Org")
(custom-put-if-not 'org-export-texinfo 'custom-version '"24.4")
(custom-put-if-not 'org-export-texinfo 'group-documentation "Options for exporting Org mode files to Texinfo.")
(custom-put-if-not 'org-export-texinfo 'custom-tag "Org Export Texinfo")
(custom-put-if-not 'org-protocol 'custom-version '"22.1")
(custom-put-if-not 'org-protocol 'group-documentation "Intercept calls from emacsclient to trigger custom actions.

This is done by advising `server-visit-files' to scan the list of filenames
for `org-protocol-the-protocol' and sub-protocols defined in
`org-protocol-protocol-alist' and `org-protocol-protocol-alist-default'.")
(custom-put-if-not 'package 'custom-version '"24.1")
(custom-put-if-not 'package 'group-documentation "Manager for Emacs Lisp packages.")
(custom-put-if-not 'package-vc 'custom-version '"29.1")
(custom-put-if-not 'package-vc 'group-documentation "Manage packages from VC checkouts.")
(custom-put-if-not 'pcl-cvs 'custom-version '"21.1")
(custom-put-if-not 'pcl-cvs 'group-documentation "Special support for the CVS versioning system.")
(custom-put-if-not 'pcomplete 'custom-version '"21.1")
(custom-put-if-not 'pcomplete 'group-documentation "Programmable completion.")
(custom-put-if-not 'pixel-fill 'custom-version '"29.1")
(custom-put-if-not 'pixel-fill 'group-documentation "Filling based on pixel widths.")
(custom-put-if-not 'plstore 'custom-version '"24.1")
(custom-put-if-not 'plstore 'group-documentation "Searchable, partially encrypted, persistent plist store.")
(custom-put-if-not 'postscript 'custom-version '"20")
(custom-put-if-not 'postscript 'group-documentation "Printing with PostScript.")
(custom-put-if-not 'postscript 'custom-tag "PostScript")
(custom-put-if-not 'printing 'custom-version '"22.1")
(custom-put-if-not 'printing 'group-documentation "Printing Utilities group.")
(custom-put-if-not 'printing 'custom-tag "Printing Utilities")
(custom-put-if-not 'profiler 'custom-version '"24.3")
(custom-put-if-not 'profiler 'group-documentation "Emacs profiler.")
(custom-put-if-not 'project 'custom-version '"28.1")
(custom-put-if-not 'project 'group-documentation "Operations on the current project.")
(custom-put-if-not 'project-linux 'custom-version '"24.3")
(custom-put-if-not 'project-linux 'group-documentation "File and tag browser frame.")
(custom-put-if-not 'project-vc 'custom-version '"25.1")
(custom-put-if-not 'project-vc 'group-documentation "VC-aware project implementation.")
(custom-put-if-not 'ps-print 'custom-version '"20")
(custom-put-if-not 'ps-print 'group-documentation "PostScript generator for Emacs.")
(custom-put-if-not 'ps-print-background 'custom-version '"20")
(custom-put-if-not 'ps-print-background 'group-documentation "Background customization.")
(custom-put-if-not 'ps-print-background 'custom-tag "Background")
(custom-put-if-not 'ps-print-color 'custom-version '"20")
(custom-put-if-not 'ps-print-color 'group-documentation "Color customization.")
(custom-put-if-not 'ps-print-color 'custom-tag "Color")
(custom-put-if-not 'ps-print-face 'custom-version '"20")
(custom-put-if-not 'ps-print-face 'group-documentation "Faces customization.")
(custom-put-if-not 'ps-print-face 'custom-tag "PS Faces")
(custom-put-if-not 'ps-print-font 'custom-version '"20")
(custom-put-if-not 'ps-print-font 'group-documentation "Fonts customization.")
(custom-put-if-not 'ps-print-font 'custom-tag "Font")
(custom-put-if-not 'ps-print-headers 'custom-version '"20")
(custom-put-if-not 'ps-print-headers 'group-documentation "Headers & footers layout.")
(custom-put-if-not 'ps-print-headers 'custom-tag "Header & Footer")
(custom-put-if-not 'ps-print-horizontal 'custom-version '"20")
(custom-put-if-not 'ps-print-horizontal 'group-documentation "Horizontal page layout.")
(custom-put-if-not 'ps-print-horizontal 'custom-tag "Horizontal")
(custom-put-if-not 'ps-print-miscellany 'custom-version '"20")
(custom-put-if-not 'ps-print-miscellany 'group-documentation "Miscellany customization.")
(custom-put-if-not 'ps-print-miscellany 'custom-tag "Miscellany")
(custom-put-if-not 'ps-print-n-up 'custom-version '"20")
(custom-put-if-not 'ps-print-n-up 'group-documentation "N-up customization.")
(custom-put-if-not 'ps-print-n-up 'custom-tag "N-Up")
(custom-put-if-not 'ps-print-page 'custom-version '"20")
(custom-put-if-not 'ps-print-page 'group-documentation "Page customization.")
(custom-put-if-not 'ps-print-page 'custom-tag "Page")
(custom-put-if-not 'ps-print-printer 'custom-version '"20")
(custom-put-if-not 'ps-print-printer 'group-documentation "Printer customization.")
(custom-put-if-not 'ps-print-printer 'custom-tag "Printer")
(custom-put-if-not 'ps-print-vertical 'custom-version '"20")
(custom-put-if-not 'ps-print-vertical 'group-documentation "Vertical page layout.")
(custom-put-if-not 'ps-print-vertical 'custom-tag "Vertical")
(custom-put-if-not 'ps-print-zebra 'custom-version '"20")
(custom-put-if-not 'ps-print-zebra 'group-documentation "Zebra customization.")
(custom-put-if-not 'ps-print-zebra 'custom-tag "Zebra")
(custom-put-if-not 'python 'custom-version '"24.3")
(custom-put-if-not 'python 'group-documentation "Python Language's flying circus support for Emacs.")
(custom-put-if-not 'python-flymake 'custom-version '"26.1")
(custom-put-if-not 'python-flymake 'group-documentation "Integration between Python and Flymake.")
(custom-put-if-not 'rcirc 'custom-version '"22.1")
(custom-put-if-not 'rcirc 'group-documentation "Simple IRC client.")
(custom-put-if-not 'recentf 'custom-version '"21.1")
(custom-put-if-not 'recentf 'group-documentation "Maintain a list of recently opened files.")
(custom-put-if-not 'rectangle 'custom-version '"25.1")
(custom-put-if-not 'rectangle 'group-documentation "Operations on rectangles.")
(custom-put-if-not 'repeat 'custom-version '"29.1")
(custom-put-if-not 'repeat 'group-documentation "Convenient way to repeat previous commands.")
(custom-put-if-not 'rst 'custom-version '"23.1")
(custom-put-if-not 'rst 'group-documentation "Support for reStructuredText documents.")
(custom-put-if-not 'rst-adjust 'custom-version '"21.1")
(custom-put-if-not 'rst-adjust 'group-documentation "Settings for adjustment and cycling of section title adornments.")
(custom-put-if-not 'rst-compile 'custom-version '"21.1")
(custom-put-if-not 'rst-compile 'group-documentation "Settings for support of conversion of reStructuredText
document with \\[rst-compile].")
(custom-put-if-not 'rst-faces 'custom-version '"21.1")
(custom-put-if-not 'rst-faces 'group-documentation "Faces used in Rst Mode.")
(custom-put-if-not 'rst-toc 'custom-version '"21.1")
(custom-put-if-not 'rst-toc 'group-documentation "Settings for reStructuredText table of contents.")
(custom-put-if-not 'ruler-mode 'custom-version '"22.1")
(custom-put-if-not 'ruler-mode 'group-documentation "Display a ruler in the header line.")
(custom-put-if-not 'savehist 'custom-version '"22.1")
(custom-put-if-not 'savehist 'group-documentation "Save minibuffer history.")
(custom-put-if-not 'ses 'custom-version '"21.1")
(custom-put-if-not 'ses 'group-documentation "Simple Emacs Spreadsheet.")
(custom-put-if-not 'ses 'custom-tag "SES")
(custom-put-if-not 'shr 'custom-version '"25.1")
(custom-put-if-not 'shr 'group-documentation "Simple HTML Renderer.")
(custom-put-if-not 'sieve 'custom-version '"22.1")
(custom-put-if-not 'sieve 'group-documentation "Manage sieve scripts.")
(custom-put-if-not 'snmp 'custom-version '"20.4")
(custom-put-if-not 'snmp 'group-documentation "Mode for editing SNMP MIB files.")
(custom-put-if-not 'soap-client 'custom-version '"24.1")
(custom-put-if-not 'soap-client 'group-documentation "Access SOAP web services from Emacs.")
(custom-put-if-not 'socks 'custom-version '"22.2")
(custom-put-if-not 'socks 'group-documentation "SOCKS support.")
(custom-put-if-not 'spam-stat 'custom-version '"22.1")
(custom-put-if-not 'spam-stat 'group-documentation "Statistical spam detection for Emacs.
Use the functions to build a dictionary of words and their statistical
distribution in spam and non-spam mails.  Then use a function to determine
whether a buffer contains spam or not.")
(custom-put-if-not 'tab-line-faces 'custom-version '"27.1")
(custom-put-if-not 'tab-line-faces 'group-documentation "Faces used in the tab line.")
(custom-put-if-not 'table 'custom-version '"22.1")
(custom-put-if-not 'table 'group-documentation "Text based table manipulation utilities.")
(custom-put-if-not 'table 'custom-tag "Table")
(custom-put-if-not 'testcover 'custom-version '"21.1")
(custom-put-if-not 'testcover 'group-documentation "Code-coverage tester.")
(custom-put-if-not 'textsec 'custom-version '"29.1")
(custom-put-if-not 'textsec 'group-documentation "Suspicious text identification.")
(custom-put-if-not 'tildify 'custom-version '"21.1")
(custom-put-if-not 'tildify 'group-documentation "Add hard spaces or other text fragments to text buffers.")
(custom-put-if-not 'todo 'custom-version '"24.4")
(custom-put-if-not 'todo 'group-documentation "Create and maintain categorized lists of todo items.")
(custom-put-if-not 'todo-categories 'custom-version '"24.4")
(custom-put-if-not 'todo-categories 'group-documentation "User options for Todo Categories mode.")
(custom-put-if-not 'todo-display 'custom-version '"24.4")
(custom-put-if-not 'todo-display 'group-documentation "User display options for Todo mode.")
(custom-put-if-not 'todo-edit 'custom-version '"24.4")
(custom-put-if-not 'todo-edit 'group-documentation "User options for adding and editing todo items.")
(custom-put-if-not 'todo-faces 'custom-version '"24.4")
(custom-put-if-not 'todo-faces 'group-documentation "Faces for the Todo modes.")
(custom-put-if-not 'todo-filtered 'custom-version '"24.4")
(custom-put-if-not 'todo-filtered 'group-documentation "User options for Todo Filter Items mode.")
(custom-put-if-not 'tramp 'custom-version '"22.1")
(custom-put-if-not 'tramp 'group-documentation "Edit remote files with a combination of ssh, scp, etc.")
(custom-put-if-not 'tree-widget 'custom-version '"22.1")
(custom-put-if-not 'tree-widget 'group-documentation "Customization support for the Tree Widget library.")
(custom-put-if-not 'treesit 'custom-version '"29.1")
(custom-put-if-not 'treesit 'group-documentation "Incremental parser.
It is used to enhance major mode features like font-lock,
indent, imenu, etc.")
(custom-put-if-not 'url 'custom-version '"22.1")
(custom-put-if-not 'url 'group-documentation "Uniform Resource Locator tool.")
(custom-put-if-not 'use-package 'custom-version '"29.1")
(custom-put-if-not 'use-package 'group-documentation "A `use-package' declaration for simplifying your `.emacs'.")
(custom-put-if-not 'use-package-ensure 'custom-version '"29.1")
(custom-put-if-not 'use-package-ensure 'group-documentation "Support for :ensure and :pin keywords in `use-package' declarations.")
(custom-put-if-not 'vc-bzr 'custom-version '"22.2")
(custom-put-if-not 'vc-bzr 'group-documentation "VC Bazaar (bzr) backend.")
(custom-put-if-not 'vc-cvs 'custom-version '"24.1")
(custom-put-if-not 'vc-cvs 'group-documentation "VC CVS backend.")
(custom-put-if-not 'vc-git 'custom-version '"24.1")
(custom-put-if-not 'vc-git 'group-documentation "VC Git backend.")
(custom-put-if-not 'vc-hg 'custom-version '"24.1")
(custom-put-if-not 'vc-hg 'group-documentation "VC Mercurial (hg) backend.")
(custom-put-if-not 'vc-rcs 'custom-version '"24.1")
(custom-put-if-not 'vc-rcs 'group-documentation "VC RCS backend.")
(custom-put-if-not 'vc-sccs 'custom-version '"24.1")
(custom-put-if-not 'vc-sccs 'group-documentation "VC SCCS backend.")
(custom-put-if-not 'vc-src 'custom-version '"25.1")
(custom-put-if-not 'vc-src 'group-documentation "VC SRC backend.")
(custom-put-if-not 'vc-svn 'custom-version '"24.1")
(custom-put-if-not 'vc-svn 'group-documentation "VC Subversion (svn) backend.")
(custom-put-if-not 'vera 'custom-version '"22.2")
(custom-put-if-not 'vera 'group-documentation "Customizations for Vera Mode.")
(custom-put-if-not 'verilog-mode 'custom-version '"22.2")
(custom-put-if-not 'verilog-mode 'group-documentation "Major mode for Verilog source code.")
(custom-put-if-not 'w32 'custom-version '"22.1")
(custom-put-if-not 'w32 'group-documentation "MS-Windows specific features.")
(custom-put-if-not 'warnings 'custom-version '"22.1")
(custom-put-if-not 'warnings 'group-documentation "Log and display warnings.")
(custom-put-if-not 'whitespace 'custom-version '"23.1")
(custom-put-if-not 'whitespace 'group-documentation "Visualize blanks (TAB, (HARD) SPACE and NEWLINE).")
(custom-put-if-not 'windmove 'custom-version '"21.1")
(custom-put-if-not 'windmove 'group-documentation "Directional selection of windows in a frame.")
(custom-put-if-not 'xref 'custom-version '"25.1")
(custom-put-if-not 'xref 'group-documentation "Cross-referencing commands.")
(custom-put-if-not 'xwidget-webkit 'custom-version '"29.1")
(custom-put-if-not 'xwidget-webkit 'group-documentation "Displaying webkit xwidgets in Emacs buffers.")

(defvar custom-versions-load-alist '(("19.29" time-stamp) ("20" ps-print ebnf2ps) ("20.1" time-stamp) ("20.3" compile xscheme find-func mailabbrev dabbrev msb vcursor debug add-log cus-edit ffap hexl diary-lib avoid rmail which-func) ("20.3.3" dos-vars) ("20.4" hilit-chg compile) ("20.8" sql) ("21.1" ezimage gnus-start speedbar debug sgml-mode cal-hebrew wid-edit fortran strokes latin1-disp dabbrev net-utils etags message nnmail cperl-mode smtpmail cus-edit gnus-agent find-func ps-print server browse-url rmailedit flyspell vc-rcs vc-cvs gnus-art hideshow rmail sendmail vc ange-ftp gnus-group add-log gnus-sum vc-sccs) ("21.3" sql gnus-agent ange-ftp) ("22" ps-print ebnf2ps) ("22.1" binhex vc comint facemenu mail-extr hi-lock dabbrev ielm descr-text uudecode hl-line find-func calendar mm-view diff-mode sql add-log time sh-script glasses gnus-int imap latin1-disp pgtk-dnd sendmail gnus-delay cus-edit make-mode vc-svn spam mml-sec view imenu pop3 gnus-msg ispell ange-ftp mml2015 compare-w deuglify locate mm-uu mml grep cal-tex mm-util gnus-score mm-decode smime shadowfile flow-fill ffap outline org-faces autorevert vc-cvs gnus-cite keypad gnus-util gnus-win diary-lib server compile gdb-mi gnus-art fortran gnus-srvr tex-mode cal-dst warnings rmail mm-url dired gnus tcl allout message gnus-start info gnus-fun gnus-agent gnus-group gnus-sum sgml-mode desktop nnmail) ("22.2" bibtex-style sql mail-source gdb-mi find-dired gnus-sum css-mode vc-hg dired desktop) ("22.3" message) ("23.1" gnus-bookmark allout fortune gnus-util dired-aux smiley imap checkdoc informat face-remap vc-git nnmail hideif pop3 fortran rmailmm vc-hg mm-decode gnus-draft pcmpl-unix misearch gnus-msg smime f90 gnus-art cus-edit copyright rmail gnus-group ffap time sendmail mm-uu server info woman bibtex browse-url vc-cvs filesets descr-text gdb-mi spam-report mml holidays gnus-sum tex-mode gnus-dired gnus calendar nnmairix epa-mail message gnus-score) ("23.2" desktop bytecomp calendar rmailmm ansi-color tramp-gvfs mm-encode comint lunar diary-lib doc-view elint message gnus-group help-fns auth-source gdb-mi dired gnus-sum) ("23.3" rmail diary-lib rmailsum calendar desktop) ("23.4" ede) ("24.1" pcmpl-unix package-x glasses ange-ftp esh-cmd ob-R esh-util em-banner find-dired gssapi mml calendar ibuffer copyright gnus-art etags gnus-picon ob-exp org-crypt facemenu em-smart em-rebind woman doc-view diary-lib tramp esh-arg em-glob esh-proc em-pred em-cmpl em-term em-dirs em-hist em-unix gnus-registry battery sieve-manage mml2015 dirtrack rmail org-fold cus-edit ob-plantuml ob-js ob-ditaa f90 elec-pair auth-source info erc-join org-entities org-inlinetask erc-backend gnus-group vc vc-sccs gnus-msg gnus esh-var org-keys gnus-util dired-x sendmail vc-svn em-ls smtpmail cc-fonts em-alias log-edit bibtex gnus-sum ox-icalendar js cus-theme smiley org-mobile ob-core vc-cvs appt mm-view gnus-int package vc-bzr allout saveplace cc-guess arc-mode esh-ext rst vc-git man ob-lisp gnus-html server shr flyspell org-refile esh-io org-faces org-capture message sql pop3 url-queue ido calc ses gnus-srvr cc-vars rcirc compile esh-mode em-script url-cache gnus-start vc-rcs hl-line org-habit emacs-lock em-prompt verilog-mode ob-tangle org-archive org-attach allout-widgets cl-indent gnus-gravatar org-ctags feedmail ox-odt prolog org-clock ol-bibtex org-list org-table image-mode browse-url ol org org-agenda gnus-search) ("24.3" server sh-script erc-backend org-capture cus-edit ob-julia ob-groovy message hexl icalendar calendar ox-odt minibuf-eldef org-datetree wdired gnus-picon ob-C which-func ido org org-id gdb-mi flymake debug calc tramp avoid gnus-msg perl-mode diff-mode ediff-wind pcmpl-gnu semantic/complete sql proced vhdl-mode erc-match ffap emacs-lock compile tramp-smb ol-doi rcirc em-term verilog-mode org-agenda cal-html man nnmail apropos pcmpl-rpm smerge-mode allout reftex-vars) ("24.4" m4-mode mml-smime man sql verilog-mode vc-svn imenu org-protocol reftex-vars tramp-smb ansi-color term org-attach-git smie js info-xref ob-lilypond flymake-proc epa tramp-adb bibtex strokes unrmail f90 hi-lock gnus-sum shr ol-gnus org-archive org-clock apropos saveplace package ob-ditaa gnus tramp-cache recentf gnus-start ob-ocaml autorevert em-term gdb-mi message idlwave type-break timeclock find-file calendar desktop cfengine sh-script gnutls ede/linux pcmpl-x org elec-pair compare-w log-edit dired org-src calc ido ob-python vhdl-mode rmail ruby-mode python ox-man ox-latex nnimap org-faces ox-html eww icomplete flymake ox-beamer mm-util org-mobile octave mml2015 ob-core info sieve-manage remember cookie1 pop3 ox flyspell tramp ox-odt doc-view org-agenda ob-ruby ox-ascii ox-texinfo) ("24.5" vc-hg erc-stamp mml2015 flyspell erc) ("25.1" diff-mode erc vc-hg checkdoc sgml-mode xt-mouse ldap info find-func check-declare gud newst-treeview url-tramp vc-cvs erc-desktop-notifications tramp-adb whitespace epg-config mm-decode gnus-sum vhdl-mode tex-mode gdb-mi cl-indent sh-script hideif vc mml-sec calendar shr gnus-registry vc-annotate verilog-mode eudc-vars newst-reader ls-lisp sql filecache browse-url package vc-git url-handlers gnus-art arc-mode rmailmm vc-bzr nsm compare-w rcirc python em-term js gnus-fun eww vc-svn rect icalendar tildify net-utils) ("25.2" ffap tramp-sh) ("26.1" ob-scheme ol-bbdb debug ob-core ob-exp org-faces org-duration cpp ox-md message perl-mode dig org-keys org-attach-git dired-x gnus-cloud tex-mode package edebug icomplete gnus-search executable url-vars dunnet flyspell ediff-init pixel-scroll org-fold org-src shr ruby-mode ol-bibtex sieve-manage enriched gnus-art ox-publish ox-odt ob-lisp ox-ascii vc-git dired tramp epa grep mhtml-mode bytecomp js org-colview ange-ftp image-dired erc dns-mode gnus-mh browse-url sql ox-beamer display-line-numbers net-utils cc-vars term ox-html mailcap vc-hg css-mode flymake ibuf-ext wdired add-log org-timer python comint org-table man org ox-latex org-agenda ibuffer ob-lua ox org-clock checkdoc org-attach image-dired-external ox-texinfo) ("26.2" shadowfile imenu calc mail-source) ("26.3" help-fns) ("27.1" esh-mode sendmail vc-hg image-mode dired-aux cua-base flymake flymake-cc ox-texinfo ido url-vars gnus-win windmove edebug nxml-mode gnus-sum gud arc-mode image-converter server erc tramp-sh epg-config gnutls bytecomp vc-dispatcher dired project flyspell tree-widget time-stamp remember verilog-mode hideif backtrace add-log flymake-proc vc-git rmailout eww man network-stream auth-source rcirc js compile thread tramp-cmds gnus-async xref shr package char-fold nsm org-agenda autoinsert display-fill-column-indicator erc-button message diff-mode bibtex bookmark pcmpl-gnu tex-mode footnote cc-vars tramp-rclone tar-mode auth-source-pass vc org comint browse-url smtpmail doc-view autorevert python mm-uu cus-edit tab-line nnmail hi-lock term winner gnus-art find-dired grep mm-decode sql tramp gravatar) ("27.2" ox-html) ("28.0" verilog-mode) ("28.1" browse-url erc-services imenu ido reveal comint reftex-vars arc-mode perl-mode log-view vc-hg ffap goto-addr autoinsert epa-mail bookmark find-func smiley windmove life tramp-gvfs tramp-smb icomplete gnus etags tramp-sshfs rmail nnimap grep info newst-treeview texinfo calc erc apropos gnus-registry nnselect bibtex battery hideshow compile vc-git calendar epa-ks xref tramp-adb mpc ethio-util help-fns time gnus-art python display-line-numbers diff-mode shortdoc image-dired tramp-fuse erc-button epa bug-reference gnus-topic hideif remember which-func smtpmail auth-source cl-indent mb-depth gnus-sum repeat rcirc tramp-crypt shell flyspell hl-line ansi-color eww project comp saveplace dired-aux term dired shr ispell tramp xwidget package server wid-edit message dictionary gdb-mi vc-dir outline bytecomp checkdoc tab-line cal-dst gnus-search) ("29.1" diff htmlfontify dired-x go-ts-mode word-wrap-mode delsel rust-ts-mode java-ts-mode pixel-fill webjump calc elide-head ange-ftp url-irc edmacro flymake glyphless-mode char-fold smime imap newst-reader tramp ansi-osc eudc-vars image-converter woman json-ts-mode rmail info xwidget vc-bzr em-ls help-mode gnus-art gnus-group cmake-ts-mode log-edit tramp-sh textsec-check tramp-cache find-func tetris emacs-news-mode typescript-ts-mode c-ts-mode gnus-html recentf string-edit toml-ts-mode hi-lock icon mml table icons pp package-vc diff-mode gnus dabbrev auth-source-pass gnus-search face-remap hashcash compile doc-view xref rmailsum vc debug dired-aux browse-url files-x battery vtable ruby-mode misc gnus-util dired em-term shr outline multisession treesit image-dired-external tramp-container sh-script eglot help-fns message nnselect package eww image-mode python term emacs-authors-mode smerge-mode gnus-sum animate ecomplete gdb-mi shell proced image-crop wallpaper rcirc cperl-mode ielm comint wdired bookmark pixel-scroll esh-var image-dired mm-decode comp ffap bib-mode project emoji esh-cmd) ("29.2" tramp tramp-sh))
  "For internal use by custom.
This is an alist whose members have as car a version string, and as
elements the files that have variables or faces that contain that
version.  These files should be loaded before showing the customization
buffer that `customize-changed' generates.")

(provide 'cus-load)

;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8-emacs-unix
;; End:

;;; cus-load.el ends here
